****************************************************************
* Program name:  assignment.sas
* Author:        Steve Ross
* Final Version: September 7, 2001
* Project:       Housing Discrimination Study (#06977-000-00)
*
* This program assignment.sas reads the raw data from the Tester
* Assignment Form (TAF) that is stored in the sas data set entitled 
* assign.ssd01.  After deleting duplicate records and other data
* control number in order to create a single record for the paired 
* assignment associated with each test.  The resulting data set
* is stored in the file fassign2.ssd01  
* 
* Input Files:	assign.ssd01
* 
* Output Files:	fassign2.ssd01 
*
****************************************************************;

options nocenter ;

libname hds2000 '/mnt/jayhawk/jayproj/hds2000' ;
filename assign '/mnt/jayhawk/jayproj/hds2000/assign.ssd01' ;
filename fassign2 '/mnt/jayhawk/jayproj/hds2000/fassign2.ssd01' ;

/*  use tester assignment forms */

data assign ;
  set hds2000.assign ;

/* create site, tenure type, and racial group identifiers */

   nsite=substr(control,1,3) ;
   ntype=substr(control,4,1) ;
   ngroup=substr(control,5,1) ;
   revid=reverse(testerid) ;
   revid=compress(revid) ;
   if control='DC-RB-2111' then del_rec=1 ;
   if control='MN-RS-1206' then del_rec=1 ;
   count=1 ;

/* if missing information on number of bedrooms required or
minimum number of bedrooms cannot be backfilled from information
available in later merged samples, then set number required
to 0.5 above minimum or set minimum to 0.5 below number required.
In a later program, this will assure that assigned bedroom required
begins at minimum and has a maximum of one above the minimum */
 
  if abedreq=-1 then do ;
    if control='NY-RH-0505' then abedreq=0.5 ;
    if control='DN-RB-1037' then abedreq=0.5 ;

    if control='MN-RS-0912' then abedreq=1.5 ;
    if control='MN-RS-0917' then abedreq=1.5 ;
    if control='MN-RS-1007' then abedreq=1.5 ;
    if control='NN-RB-2432' then abedreq=1.5 ;
    if control='NO-SB-0805' then abedreq=1.5 ;

    if control='CH-RH-0903' then abedreq=2.5 ;
    if control='NY-RB-0603' then abedreq=2.5 ;
    if control='HO-SH-1934' then abedreq=2.5 ;
    if control='SA-RH-2429' then abedreq=2.5 ;
    end ;

    if abedmin=-1 then do ;
       if       control='DN-SH-0504' or      control='NY-SH-1424' or
                control='CH-SH-0806' or      control='LA-SK-1313' or
                control='SD-RH-1226' or      control='NY-SB-1007' 
                then abedmin=0.5 ;
       end ;



/*  Correction of apricell and apricehl in numeric
variables npricell and npricehl */
 
  if substr(control,4,1)='R' then do ;

/* remove spaces */

  apricehl=compress(apricehl) ;
  apricell=compress(apricell) ;

/* identify cases where the entire range was entered into a single
record or cases where either the upper or lower value was missing */

  if (substr(apricehl,4,1)='-' or substr(apricehl,5,1)='-') 
       and apricell='' then apricell=apricehl ;
  if substr(apricell,2,1)='-' and apricehl='' then apricehl=apricell ;

/* remove text from statement concerning price range */

  apricell=compress(apricell,",$upto") ;

  apricehl=compress(apricehl,",$mMaxuptoles()rUL") ;

/* finally remove any remaining dashes */

  if substr(apricell,2,1)='-' then apricell='0' ;
  if substr(apricehl,2,1)='-' then apricehl=substr(apricehl,3,4) ;
  if substr(apricehl,4,1)='-' then apricehl=substr(apricehl,5,4) ;
  if substr(apricehl,5,1)='-' then apricehl=substr(apricehl,6,4) ;

  npricell=0.0 ;
  npricehl=0.0 ;

  npricell=apricell ;
  npricehl=apricehl ;
  if npricehl=0 then npricehl=. ;

  end ;


/* delete known duplicate observations */

   if duplicat=1 or del_rec=1 then delete ;
   else output assign ;


proc sort ; by control testerid ;

/* check for remaining duplicates by search for instances where
more than one record exists for a given control number and tester id */

proc means noprint ;
    by control testerid ;
  var count ; output out=dupl sum=totcnt ;

proc freq ; tables totcnt ;

proc sort data=assign ; by control ;

/* check for complete tests where there are two records for each
control number */

proc means noprint data=assign ;
    by control ;
  var count ; output out=dupl2 sum=totcnt2 ;

proc freq ; tables totcnt2 ;

/* separate white and minority assignments */

data massign wassign xassign ;
  set assign ;

/* fix missing race information by examining the race information
provided by the same tester for other test */

  if control='PX-SN-2103' and tester='Mary Chiago' then arace1=7 ;
  if control='PX-SN-2103' and tester='Daphne Collins' then  arace1=1 ; 
  if control='AU-RB-1328' and tester='Carlos Johnson' then       arace1=2 ;
  if control='CH-RH-0704' and tester='Nicole Barder' then        arace1=3 ;
  if control='CH-RH-0812' and tester='Nicole Barder' then        arace1=3 ;
  if control='CH-RH-0911' and tester='Monica Ribbeck' then       arace1=3 ;
  if control='CH-SH-0908' and tester='Elizabth Hayes' then       arace1=3 ;
  if control='CX-RB-2906' and tester='Angela Jones' then         arace1=2 ;
  if control='DC-RB-0914' and tester='Hosia Gardner' then        arace1=2 ;
  if control='DN-RH-1421' and tester='Helen Giron' then          arace1=3 ;
  if control='DN-RH-1619' and tester='Paul  Lopez' then          arace1=3 ;
  if control='DN-RH-2010' and tester='Johnny Maguire' then       arace1=3 ;
  if control='DN-SB-0606' and tester='Troy Grimes' then          arace1=2 ;
  if control='DN-SH-1806' and tester='Gwylym Cano' then          arace1=3 ;
  if control='DN-SH-1821' and tester='Sandra Herrera' then       arace1=3 ;
  if control='HO-SB-1304' and tester='Cindy McCain' then         arace1=2 ;
  if control='NY-RH-1304' and tester='Tony Morales' then         arace1=3 ;
  if control='NY-SB-1108' and tester='Steve Bagley' then         arace1=2 ;
  if control='NY-SB-3109' and tester='Salesia Kiyyel' then       arace1=2 ;
  if control='PX-RN-2303' and tester='Mai Chischilly' then       arace1=7 ;
  if control='PX-RN-2404' and tester='Mae Cluschily' then        arace1=7 ;
  if control='PX-RN-2502' and tester='Mae Cluschily' then        arace1=7 ;
  if control='PX-RN-2512' and tester='Mary Chiago' then          arace1=7 ;
  if control='PX-SN-2001' and tester='Mae Cluschily' then        arace1=7 ;
  if control='TC-SH-0602' and tester='George Ornelias' then      arace1=3 ;
  if control='CH-RB-1813' and tester='Debbie Benney' then        arace1=1 ;
  if control='DS-SB-0610' and tester='Deron Schwieterman' then   arace1=1 ;
  if control='DT-RB-0921' and tester='Laura Graham' then         arace1=1 ;
  if control='LA-RK-0328' and tester='Melanie Blunchi' then      arace1=1 ;
  if control='LA-RK-0812' and tester='Erik  Knutzen' then        arace1=1 ;
  if control='LA-SB-1208' and tester='Don Mandigo' then          arace1=1 ;
  if control='MA-RB-0803' and tester='Chris Beals' then          arace1=1 ;
  if control='MA-RB-0925' and tester='Chris Beals' then          arace1=1 ;
  if control='NY-SB-0401' and tester='Adam Schartoff' then       arace1=1 ;
  if control='PU-SH-1507' and tester='Diane Oreskovich' then     arace1=1 ;
  if control='PU-SH-1517' and tester='Lisa Lehew' then           arace1=1 ;
  if control='SD-SH-0805' and tester='Kathleen Schamel' then     arace1=1 ;
  if control='SD-SH-1501' and tester='David Kline' then          arace1=1 ;
  if control='SD-SH-1905' and tester='Andrew Mikluskck' then     arace1=1 ;
  if control='SD-SH-2011' and tester='David Kline' then          arace1=1 ;
  if control='SD-SH-2022' and tester='David Kline' then          arace1=1 ;
  if control='SD-SH-2120' and tester='David Kline' then          arace1=1 ;
  if control='SD-SH-2314' and tester='David Kline' then          arace1=1 ;
  if control='TC-RH-0517' and tester='Jeff Richardson' then      arace1=1 ;

/* fix missing or inconsistent information on price requirements by 
comparing to price range assigned to the second tester */


   if control='LA-RC-1018' and testerid='339' then npricehl=3200 ;
   if control='HO-RB-2819' and testerid='118' then npricell=895 ;
   if control='AU-RH-1502' and testerid='02-203' then npricehl=1400 ;
   if control='DN-RH-1129' and testerid='413' then npricehl=1000 ;
   if control='DC-RB-1615' and testerid='302' then npricehl=1300 ;

/* output unambiguously white assignments to wassign, unambiguously
minority assignments to massign, and all other assignments to 
xassign */

  if arace1=1 then output wassign ;
   else if arace1=0 or arace1=8 then output xassign ;
   else output massign ;

/* save assignment information for white tester into new variable names */

data wassign ;
  set wassign ;
  wtestid=testerid ;
  wtestnm=tester ;
  wrace=arace1 ;
  wage=aage1 ;
  wsex=agendr1 ;
  wincome=aincmont ;
  wincom2=aincyrt ;
  wmarried=0 ;
  if arelate2=2 or arelate3=2 or arelate4=2 or arelate5=2
    or arelate6=2 then wmarried=1 ;
  wchild=0 ;
  if arelate2=3 or arelate3=3 or arelate4=3 or arelate5=3
    or arelate6=3 then wchild=1 ;
  wtotasst=atotasst ;
  wcrdbal=acrdbalt ;
  wcrdpay=acrdmont ;
  wrent=arentnow ;
  wlength=atenure ;
  wbedreq=abedreq ;
  wbedmin=abedmin ;
  whometyp=ahometyp ;
  wsitenam=asitenam ;
  wsitestr=asitestr ;
  wsitecit=asitecit ;
  wsitesta=asitesta ;
  wtype=atsttype ;
  wpricell=npricell ;
  wpricehl=npricehl ;
  wdate_y=adate_y ;
  wdate_m=adate_m ;
  wdate_d=adate_d ;
  keep control wtype wtestid wrace wage wsex wincome wmarried
    wchild wtotasst wcrdbal wcrdpay wrent wlength wbedreq
    wbedmin whometyp wtestnm wsitenam wsitestr wsitecit wsitesta 
    wpricell wpricehl wdate_y wdate_m wdate_d wincom2;

proc sort ; by control ;

/* save assignment information for minority tester into new variable names */


data massign ;
  set massign ;
  mtestid=testerid ;
  mtestnm=tester ;
  mrace=arace1 ;
  mage=aage1 ;
  msex=agendr1 ;
  mincome=aincmont ;
  mincom2=aincyrt ;
  mmarried=0 ;
  if arelate2=2 or arelate3=2 or arelate4=2 or arelate5=2
    or arelate6=2 then mmarried=1 ;
  mchild=0 ;
  if arelate2=3 or arelate3=3 or arelate4=3 or arelate5=3
    or arelate6=3 then mchild=1 ;
  mtotasst=atotasst ;
  mcrdbal=acrdbalt ;
  mcrdpay=acrdmont ;
  mrent=arentnow ;
  mlength=atenure ;
  mbedreq=abedreq ;
  mbedmin=abedmin ;
  mhometyp=ahometyp ;
  msitenam=asitenam ;
  msitestr=asitestr ;
  msitecit=asitecit ;
  msitesta=asitesta ;
  mtype=atsttype ;  
  mpricell=npricell ;
  mpricehl=npricehl ;
  mdate_y=adate_y ;
  mdate_m=adate_m ;
  mdate_d=adate_d ;
  keep control mtestid mrace mage msex mincome mmarried
    mchild mtotasst mcrdbal mcrdpay mrent mlength mbedreq mtype
    mbedmin mhometyp mtestnm msitenam msitestr msitecit msitesta 
    mpricell mpricehl mdate_y mdate_m mdate_d mincom2;


proc sort ; by control ;

/* save assignment information when race is not known */

data xassign ;
  set xassign ;
  xtestid=testerid ;
  xtestnm=tester ;
  xrace=arace1 ;
  xage=aage1 ;
  xsex=agendr1 ;
  xincome=aincmont ;
  xincom2=aincyrt ;
  xmarried=0 ;
  if arelate2=2 or arelate3=2 or arelate4=2 or arelate5=2
    or arelate6=2 then xmarried=1 ;
  xchild=0 ;
  if arelate2=3 or arelate3=3 or arelate4=3 or arelate5=3
    or arelate6=3 then xchild=1 ;
  xtotasst=atotasst ;
  xcrdbal=acrdbalt ;
  xcrdpay=acrdmont ;
  xrent=arentnow ;
  xlength=atenure ;
  xbedreq=abedreq ;
  xbedmin=abedmin ;
  xhometyp=ahometyp ;
  xtype=atsttype ;
  xsitenam=asitenam ;
  xsitestr=asitestr ;
  xsitecit=asitecit ;
  xsitesta=asitesta ;
  xtype=atsttype ;  
  xpricell=npricell ;
  xpricehl=npricehl ;
  xdate_y=adate_y ;
  xdate_m=adate_m ;
  xdate_d=adate_d ;


  keep control xtype xtestid xrace xage xsex xincome xmarried
    xchild xtotasst xcrdbal xcrdpay xrent xlength xbedreq
    xbedmin xhometyp xtestnm xsitenam xsitestr xsitecit xsitesta 
    xpricell xpricehl  xdate_y xdate_m xdate_d xincom2 ;

/* Merge the sample of white assignments for each test
with minority and unlabelled assignments. If an unlabelled
assignment matches and a minority assignment does not match
the white assignment, code the unlabelled assignment as
minority */

proc sort ; by control ;

data  wassign junk1 ;
  merge wassign (in=q1) massign (in=q2) xassign (in=q3) ;
  by control ;  if q1 ;

/* save new minority tester information */

  if q2=0 and q3=1 then do ;
  mtestid=xtestid ;
  mtestnm=xtestnm ;
  mrace=xrace ;
  mage=xage ;
  msex=xsex ;
  mincome=xincome ;
  mincom2=xincom2 ;
  mmarried=xmarried ;
  mchild=xchild ;
  mtotasst=xtotasst ;
  mcrdbal=xcrdbal ;
  mcrdpay=xcrdpay ;
  mrent=xrent ;
  mlength=xlength ;
  mbedreq=xbedreq ;
  mbedmin=xbedmin ;
  mhometyp=xhometyp ;
  msitenam=xsitenam ;
  msitestr=xsitestr ;
  msitecit=xsitecit ;
  msitesta=xsitesta ;
  mtype=xtype ;
  mpricell=xpricell ;
  mpricehl=xpricehl ;
  mdate_y=xdate_y ;
  mdate_m=xdate_m ;
  mdate_d=xdate_d ;
     end ;

/* output all white assignments that found any match */

  if q2=1 or q3=1 then output wassign ; 
     else output junk1 ;

/* verify that all white assignments found a match */

data junk1 ;
  set junk1 ;
  keep control mtestid mtestnm mincome ;
proc print ;

/* Merge the sample of minority assignments for each test
with white and unlabelled assignments. If an unlabelled
assignment matches and a white assignment does not match
the minority assignment, code the unlabelled assignment as
white */

data  massign junk2 ;
  merge wassign (in=q1) massign (in=q2) xassign (in=q3) ;
  by control ;  if q2 ;

/* save new white tester information */

  if q1=0 and q3=1 then do ;
  wtestid=xtestid ;
  wtestnm=xtestnm ;
  wrace=1 ;
  wage=xage ;
  wsex=xsex ;
  wincome=xincome ;
  wincom2=xincom2 ;
  wmarried=xmarried ;
  wchild=xchild ;
  wtotasst=xtotasst ;
  wcrdbal=xcrdbal ;
  wcrdpay=xcrdpay ;
  wrent=xrent ;
  wlength=xlength ;
  wbedreq=xbedreq ;
  wbedmin=xbedmin ;
  whometyp=xhometyp ;
  wsitenam=xsitenam ;
  wsitestr=xsitestr ;
  wsitecit=xsitecit ;
  wsitesta=xsitesta ;
  wtype=xtype ;
  wpricell=xpricell ;
  wpricehl=xpricehl ;
  wdate_y=xdate_y ;
  wdate_m=xdate_m ;
  wdate_d=xdate_d ;
    end ;


/*  output any additional minority assignments that matched with
unlabelled assignments */ 

  if q1=0 and q3=1 then output massign ;
    else if q1=0 and q3=0 then output junk2 ;
     else delete ;

/* verify that all minority assignments found a match */

data junk2 ;
  set junk2 ;
  keep control mtestid mtestnm mincome ;
proc print ;

/* verify that all assignments found a match */

data  junk3 ;
  merge wassign (in=q1) massign (in=q2) xassign (in=q3) ;
  by control ;    if q3 ;

    
    if q1=0 and q2=0 then output junk3 ;
      else delete ;


data junk3 ;
  set junk3 ;
  keep control xtestid xtestnm xincome ;
proc print ;


/* append sample extra minority tests (found match from unlabelled
assignments to the full sample of tests based on white assignment 
matches */

data fassign ;
  set wassign massign ;
  group=substr(control,1,5) ;
  count=1 ;

/* more fixes to missing race data */

  if control='AU-SB-1406' and mtestnm='Morris Overstreet' then       mrace=2 ;
  if control='AZ-RN-1701' and mtestnm='Yolanda Ortiz' then           mrace=3 ;
  if control='CH-RH-1219' and mtestnm='Francisco J. Vivar' then      mrace=3 ;
  if control='MN-RS-1614' and mtestnm='Norkov Theio' then            mrace=4 ;
  if control='MN-RS-1807' and mtestnm='Terri Thao' then              mrace=4 ;
  if control='MN-SS-0902' and mtestnm='Bo Thao' then                 mrace=4 ;
  if control='MN-SS-0907' and mtestnm='Nlo Kou Thao' then            mrace=4 ;
  if control='NY-RB-0613' and mtestnm='Karen Welsber' then           mrace=2 ;
  if control='NY-SB-3108' and mtestnm='Sabrina Kizzie' then          mrace=2 ;
  if control='PT-RB-2009' and mtestnm='Donna Proctor' then           mrace=2 ;
  if control='PX-RN-2205' and mtestnm='Toby Radcliff' then           mrace=7 ;
  if control='PX-RN-2612' and mtestnm='Mary Chiago' then             mrace=7 ;
  if control='PX-SN-2104' and mtestnm='Mae Chischilly' then          mrace=7 ;
  if control='SA-RH-0902' and mtestnm='Jennifer wengor' then         mrace=3 ;


  keep group control mtestid wtestid mtestnm wtestnm 
       wincome mincome wincom2 mincom2 
       count mrace wrace mtype wtype
       wage mage wsex msex wmarried mmarried wchild mchild
       wtotasst mtotasst wcrdbal mcrdbal wcrdpay mcrdpay
       wrent mrent wlength mlength wbedreq mbedreq wbedmin mbedmin
       whometyp mhometyp wsitenam wsitesta wsitecit wsitestr   
       msitenam msitesta msitecit msitestr 
        wpricehl wpricell mpricehl mpricell  
        wdate_y wdate_m wdate_d mdate_y mdate_m mdate_d ;

proc sort ;
   by control ;

/* verify that all tests have complete racial information */

data test ;
  set fassign ;
  if mrace=0 or mrace=8 then output test ;
    else delete ; 


/* write results to permenant sas data set */

data hds2000.fassign2 ;
  set fassign ;
  ntype=substr(control,4,1) ;

run;
	

