****************************************************************
* Program name:  batch_edits.sas
* Project:       Housing Discrimination Study Phase I
*
*  Created on:    January, 2001 by Chris Snow
*  Revised on:    April, 2001 by Beata Bednarz
*  Final version: August, 2001 by Steve Ross
*
* This makes several simple batch edits to the HDS data files:
* 1)subtracts 12 from military hours between 13 and 24; 
* 2)changes ARELATE1 (relationship to tester) to 1 in all cases.
* 3)changes all year variables to 2000 except those = 1 or 2001.
* 4)converts several character variables to numeric, after first 
*   setting any cases with character values.
*
*  Note that this program is identical to the batch_edits_cs program
*  created by the Urban Institute except that it removes code that
*  forced the data to conform to the skip patterns imposed by the
*  survey instruments even when the respondent did not actually 
*  follow the skip patterns.  This information was important in order
*  to be able to fully analyze a testers responses.     
*
* Input Files:   appointm, assignme, followup, q17,
*                 rental, sales, moresale,
*                 nbrhood, rechomes
* Output Files:  hds.appointm, hds.assignme, hds.followup, hds.q17, 
*                 hds.rental, hds.sales, hds.moresale,
*                 hds.nbrhood, hds.rechomes
*
*  Comments: Prior to making any conversions of char to numeric 
*            variables it was absolutely crucial to verify 
*            frequencies of the variables being converted to 
*            devise proper code.
*                                            
****************************************************************;

libname hds '/mnt/jayhawk/jayproj/hds2000' ;

filename appointl '/mnt/jayhawk/jayproj/hds2000/appointl.ssd01' ;
filename assign '/mnt/jayhawk/jayproj/hds2000/assign.ssd01' ;
filename foluplog '/mnt/jayhawk/jayproj/hds2000/foluplog.ssd01' ;
filename q17 '/mnt/jayhawk/jayproj/hds2000/q17.ssd01' ;
filename rental '/mnt/jayhawk/jayproj/hds2000/rental.ssd01' ;
filename sales '/mnt/jayhawk/jayproj/hds2000/sales.ssd01' ;
filename moresale '/mnt/jayhawk/jayproj/hds2000/moresale.ssd01' ;
filename neighbrh '/mnt/jayhawk/jayproj/hds2000/neighbrh.ssd01' ;
filename rechomes '/mnt/jayhawk/jayproj/hds2000/rechomes.ssd01' ;


*OK********* APPOINTMENT CALL FORM **************************;

data hds.appointl;
  set hds.appointl ;

****Converts military to standard time****;
  if 12< CAPTT_H <=24 then 
    do;
       CAPTT_H = CAPTT_H -12;
       CAPTT_AM = 2;
       *put Control= testerid= 'Subtracted 12 from CAPTT_H';
    end;
  
  if 12< CTIME_H <=24 then 
    do;
       CTIME_H = CTIME_H -12; 
       CTIME_AM = 2;
       *put Control= testerid= 'Subtracted 12 from CTIME_H';
    end;
  
  
****Sets appointment year to 2000 or 2001****;
  if CAPTD_Y not in (99,1999,1,2001) THEN CAPTD_Y = 2000;
  else if CAPTD_Y = 1 then CAPTD_Y = 2001;
  
****Sets year of call to 2000 or 2001****;
  if CDATE_Y not in (99,1999,1,2001) THEN CDATE_Y = 2000;
  else if CDATE_Y = 1 then CDATE_Y = 2001;

proc contents ;


run;


*OK********* TESTER ASSIGNMENT FORM *****************************;

data hds.assign ;
 ****RENAME CHARACTER VARIABLES TO ALLOW LATER CONVERSION TO NUMERIC****;
 set hds.assign (
               rename=(AINCMON1=INCMON1 AINCMON2=INCMON2 
                       AINCMON3=INCMON3 AINCMON4=INCMON4
                       AINCMON5=INCMON5 AINCMON6=INCMON6
                       AINCYR1=INCYR1 AINCYR2=INCYR2 
                       AINCYR3=INCYR3 AINCYR4=INCYR4 
                       AINCYR5=INCYR5 AINCYR6=INCYR6 
                       ABEDMIN=BEDMIN ABEDREQ=BEDREQ)) ;
 length AINCMON1-AINCMON6 8. AINCYR1-AINCYR6 8.;


  if ARELATE1 = 0  then 
    do; ****Self referential, must always = 1****;
       ARELATE1 = 1;
    end;
  
  if ADATE_Y not in (99,1999,0,2000) then 
    do;
       if ADATE_Y in (1,2001) then 
         do;
            ADATE_Y = 2001; ****Sets year housing needed to 2001****;
         end;
       else
         do;
            ADATE_Y = 2000;
            *put Control= testerid= ADATE_Y= 'Reset year housing needed to 2000';
         end;
    end;


****BEDMIN RETAINS THE ORIGINAL *RAW* VALUES OF ABEDMIN, ABEDMIN BECOMES A NUMERIC VARIABLE****;

****Sets ABEDMIN to 0 for studios/efficiencies/bachelors/lofts and 1 for singles****;
****Where number cannot be determined set ABEDMIN to -1****;
****For the remainder set ABEDMIN to 2,3,4,5 where applicable****;

  if ( index(upcase(BEDMIN),"ST")>0 
      or index(upcase(BEDMIN),"EF")>0 
      or index(upcase(BEDMIN),"BAC")>0
      or index(upcase(BEDMIN),"LOFT")>0 
      or (compress(BEDMIN) in ("sytudio","srudio")) ) then ABEDMIN = 0;
  else if index(upcase(BEDMIN),"SI")>0 then ABEDMIN = 1;
  else ABEDMIN = input(compress(BEDMIN,"+`abcdefghijklmnopqrstuvwxyz"),8.);

 

**** A FEW SUGGESTED CORRECTIONS TO THE NEW ABEDMIN VALUES ****;

/*** 
     VERIFIED THAT OBS WITH CONTROL 'OR-RB-1027' AND TESTERID '22' HAS ABEDMIN = '6'
     ABEDMIN SHOULD BE CHANGED TO '3' B/C THE OTHER TESTER HAS THE SAME ABEDREQ AND ABEDMIN = '3'

     VERIFIED THAT OBS WITH CONTROL 'NN-RH-2208' HAS ABEDMIN = 'qbr'
     ABEDMIN SHOULD BE CHANGED TO '1br' INSTEAD
 
     THERE ARE 7 OBS WHERE ABEDMIN = 's' 
     CONTROL     TESTERID  ABEDREQ  ABEDMIN  SUGGESTED_VAL_FOR_ABEDMIN
     DN-SH-0504  09        3        s        studio or single (the other tester has ABEDMIN=2)
     CH-SH-0806  hm-sanc   studio   s        studio
     CH-SH-0806  wm-gram   studio   s        studio
     LA-SK-1313  133       3        s        single (the other tester has ABEDMIN=2)
     NY-SB-1007  18        1        s        studio or single (the other tester has ABEDMIN=studio)
     NY-SH-1424  07        1        s        studio or single (the other tester has ABEDMIN=studio)
     SD-RH-1226  21        1        s        studio or single (the other tester has ABEDMIN=studio)
     
     THE CODE BELOW ASSIGNS A VALUE OF -1 TO ABEDMIN FOR THESE 7 OBSERVATIONS
***/
     
     
  if trim(BEDMIN) = "6" then ABEDMIN = 3;
  if trim(BEDMIN) = "qbr" then ABEDMIN = 1;
  if trim(BEDMIN) = "s" then ABEDMIN = -1;


****Sets ABEDREQ to 0 for studios/efficiencies/bachelors/lofts and 1 for singles****;
****Where number cannot be determined set ABEDREQ to -1****;
****For the remainder set ABEDMIN to 2,3,4,5 where applicable****;

  if indexc(BEDREQ,"1234567890")=0 then
    do;
       if ( index(upcase(BEDREQ),"ST")>0 
           or index(upcase(BEDREQ),"EF")>0 
           or index(upcase(BEDREQ),"BAC")>0
           or index(upcase(BEDREQ),"LOFT")>0 ) then ABEDREQ = 0;
       else if ( index(upcase(BEDREQ),"SI")>0 ) then ABEDREQ = 1;
          *Correct values for two odd obs*;
          *OBS WITH CONTROL 'DN-RH-0617' TESTERID '053' HAS ABEDREQ = 'i'*;
          *CHANGE ABEDREQ TO '1' B/C THE OTHER TESTER HAS THE SAME ABEDMIN and ABEDREQ = '1'*;
       else if trim(BEDREQ)="i" then ABEDREQ = 1;
          *OBS WITH CONTROL 'PX-RN-1102' TESTERID '106' HAS ABEDREQ = 'laura'*;
          *CHANGE ABEDREQ TO '2' B/C A DUPLICATE REC FOR THE SAME TESTER HAS ABEDREQ = '2'*;
       else if trim(BEDREQ)="laura" then ABEDREQ = 2;
    end;
  else /* if indexc(BEDREQ,"1234567890")>0 */
    do;
       if indexc(upcase(BEDREQ),"+-_/ABCDEFGHIJKLMNOPQRSTUVWXYZ")>0 then
         do;
            if (index(upcase(BEDREQ),"LOFT")>0 
               or index(upcase(BEDREQ),"DEN")>0
               or index(upcase(BEDREQ),"OR")>0
               or index(BEDREQ,"-")>0) then ABEDREQ = -1;
            else ABEDREQ = input(compress(BEDREQ,"bdrm"),8.);
         end;
       else ABEDREQ = input(compress(BEDREQ),8.); 
    end;
    

****INCMON1-INCMON6 AND INCYR1-INCYR6 RETAIN THE ORIGINAL *RAW* VALUES OF INCOME VARIABLES****;
****AINCMON1-AINCMON6 AND AINCYR1-AINCYR6 GET ASSIGNED A NUMERIC TYPE****;

  array INCMON{6} INCMON1-INCMON6;
  array AINCMON{6} AINCMON1-AINCMON6;
  array A{6} A1-A6;
  array INCYR{6} INCYR1-INCYR6;
  array AINCYR{6} AINCYR1-AINCYR6;
  array B{6} B1-B6;


do i = 1 to 6;

  if INCMON{i} = "" then 
    do;
       A{i} = "";
       AINCMON{i} = .;
    end;
  else 
    do;
       if indexc(upcase(INCMON{i}),"-/ABCDEFGHIJKLMNOPQRSTUVWXYZ?") ne 0 then
         do;
            A{i} = "-1";
            *put CONTROL= TESTERID= INCMON{i}=    '-- LETTER CHARS PRESENT IN INCMON FIELD';
         end;
       else
         do;
            A{i} = compress(INCMON{i},"~`,$");
         end;
       AINCMON{i} = input(A{i},32.);
    end;
  
   
  if INCYR{i} = "" then
    do;
       B{i} = "";
       AINCYR{i} = .;
    end;
  else
    do; 
       if indexc(upcase(INCYR{i}),"-/ABCDEFGHIJKLMNOPQRSTUVWXYZ?") ne 0 then
         do;
            B{i} = "-1";
            *put CONTROL= TESTERID= INCYR{i}=    '-- LETTER CHARS PRESENT IN INCYR FIELD';
         end;
       else
         do;
            B{i} = compress(INCYR{i},"~`,$");
         end;
       AINCYR{i} = input(B{i},32.);
    end;
end;
 
  drop A1-A6 B1-B6;

proc contents ;

run;


*OK************ LOG OF FOLLOW UP CONTACT*****************;

data hds.foluplog ;
  set hds.foluplog ;


****Converts military to standard time****;
  if 12< LTIME_H <=24 then 
    do;
       LTIME_H = LTIME_H - 12; 
       LTIME_AM = 2;
       *put Control= testerid= 'Subtracted 12 from LTIME_H';
    end;
  
****Sets year of contact to 2000****;
  if LDATE_Y not in (99,1999,1,2001) THEN LDATE_Y = 2000;

proc contents ;


run;


*OK************* RENTAL QUESTION 17 *******************;

data hds.q17;
 set hds.q17 (rename=(rubed1=rubed));
 length RUBED1 8.;


****Sets RUBED1 to 0 for studios/effic/bachelor/lofts and 1 for singles****;
****Set RUBED1 to 0,1,2,3,4,5,6,11 where applicable****;
****Where number cannot be determined set RUBED1 to -1****;
  
  if substr(upcase(RUBED),1,2) in ('ST','EF','BA') and indexc(upcase(RUBED),'/')=0 then RUBED1 = 0;
  else if substr(upcase(RUBED),1,2) = 'SI' and indexc(upcase(RUBED),'/')=0 then RUBED1 = 1;
  else if substr(upcase(RUBED),1,4) in ('0-ST','0/ST') then RUBED1 = 0;
  else if index(upcase(RUBED),'LOFT')>0 and indexc(RUBED,'/2')=0 then RUBED1 = 0;
  else if index(upcase(RUBED),'STUDIO')>0 and indexc(RUBED,'/')=0 then RUBED1 = 0;
  else if index(upcase(RUBED),'SINGLE')>0 and indexc(RUBED,'1')>0 then RUBED1 = 1;
  else if trim(RUBED) in ('0','1','2','3','4','5','6','11') then RUBED1 = input(trim(RUBED),8.);
  else if trim(RUBED)='00' then RUBED1 = 0;
  else if trim(RUBED)='01' then RUBED1 = 1;
  else if trim(RUBED)='02' then RUBED1 = 2;
  else RUBED1 = -1;
 
  /*THIS RESOLVES THE FOLLOWING:
    'Eff' 'EFF' 'Eff.' 'STUDIO' 'Studio' 'bachelor' 'efficiency' 'studio (mid-size)' 'studo'    
    'Single' 'single' '0-Studio' '0/studio' '(Loft)' 'Loft' 'huge loft' 'Lrg. studio' '0 (studio)'
    '1 (single)'
    BUT DOES NOT RESOLVE:
    'single/studio' '2 and loft' or 'loft (2 floor)' 'studio/loft' or 'single/studio' '0 (Single)'
    and many other (see PROC FREQ output for RUBED1)
   */  

****Sets year rental unit is available to 2000****;
  if RUAVLBL3 not in (99,1999,1,2001) THEN RUAVLBL3 = 2000;

proc contents ;

run;

*OK********** RENTAL SITE VISIT FORM *************;

data hds.rental ;
  ****RENAME CHARACTER VARIABLES****;
  set hds.rental (
                  rename=(RTOTUNIT=RTOTUN RWAITTIM=RWAITT));
  length RTOTUNIT 8. RWAITTIM 8.;
  
****Conversts military to standard time****;
  if 12< RAPPT_H <=24 then do;
   RAPPT_H = RAPPT_H -12;
   RAPPT_AM = 2;
   *put Control= testerid= 'Subtracted 12 from RAPPT_H';
  end;
  
  if 12< RBEGT_H <=24 then do;
   RBEGT_H = RBEGT_H -12;
   RBEGT_AM = 2;
   *put Control= testerid= 'Subtracted 12 from RBEGT_H';
  end;
  
  if 12< RENDT_H <=24 then do;
   RENDT_H = RENDT_H -12;
   RENDT_AM = 2;
   *put Control= testerid= 'Subtracted 12 from RENDT_H';
  end;
  
  if 12< RTMRT_H <=24 then do;
   RTMRT_H = RTMRT_H -12;
   RTMRT_H = 2;
   *put Control= testerid= 'Subtracted 12 from RTMRT_H';
  end;

****Sets year of report to 2000****;
  if RDATR_Y not in (99,1) THEN RDATR_Y = 2000;
****Sets test year to 2000****;
  if RDATE_Y not in (99,1) THEN RDATE_Y = 2000;
   

****Converts RTOTUNIT and RWAITTIM from character to numeric variables****;
****The original raw data is retained in RTOTUN and RWAITT variables respectively****;
  
  if indexc(upcase(RTOTUN),'`/+-ABCDEFGHIJKLMNOPQRSTUVWXYZ?<>')=0 then RTOTUNIT = input(compress(RTOTUN),8.);
  else RTOTUNIT = -1;
  
  if indexc(upcase(RWAITT),'`/+-ABCDEFGHIJKLMNOPQRSTUVWXYZ?<>')=0 then 
    do;
       RWAITTIM = input(compress(RWAITT),8.);
    end;
  else 
    do;
       if trim(upcase(RWAITT)) in ('ZERO','NONE') then RWAITTIM = 0;
       else if trim(upcase(RWAITT)) = '3HR' then RWAITTIM = 180;
       else if index(upcase(RWAITT),'30 SEC') then RWAITTIM = .5;
       else if index(upcase(RWAITT),'10 SEC') then RWAITTIM = .166;
       else if index(upcase(RWAITT),'5 SEC') then RWAITTIM = .083;
       else RWAITTIM = -1;
    end;

proc contents ;

run;


*OK********** SALES SITE VISIT FORM ****************;

data hds.sales;
  set hds.sales (
                 rename=(STOTUNIT=STOTUN 
                         SDWNHIA =DWNHIA
                         SDWNLOWA=DWNLOWA
                         SDWNHIP =DWNHIP
                         SDWNLOWP=DWNLOWP));
  length STOTUNIT 8. SDWNHIA 8. SDWNLOWA 8. SDWNHIP 8. SDWNLOWP 8. ;

  

****Conversts military to standard time****;
  if 12< SAPPT_H <=24 then do;
   SAPPT_H = SAPPT_H -12; 
   SAPPT_AM = 2;
   *put Control= testerid= 'Subtracted 12 from SAPPT_H';
  end;
  
  if 12< SBEGT_H <=24 then do;
   SBEGT_H = SBEGT_H -12; 
   SBEGT_AM = 2;
   *put Control= testerid= 'Subtracted 12 from SBEGT_H';
  end;
  
  if 12< SENDT_H <=24 then do;
   SENDT_H = SENDT_H -12; 
   SENDT_AM = 2;
   *put Control= testerid= 'Subtracted 12 from SENDT_H';
  end;
  
  if 12< STIME_H <=24 then do;
   STIME_H = STIME_H -12; 
   STIME_AM = 2;
   *put Control= testerid= 'Subtracted 12 from STIME_H';
  end;

****Sets test year to 2000****;
  if SDATE_Y not in (99,1999,1,2001) THEN SDATE_Y = 2000;


****Convert STOTUNIT from character to numeric variables****;
****STOTUN retains the original raw data in a character format****;

  if indexc(upcase(STOTUN),'/.+-ABCDEFGHIJKLMNOPQRSTUVWXYZ?$<>')=0 then
    do;
       if compress(STOTUN) in ('01','07','09') then STOTUNIT = input(compress(STOTUN,'0 '),8.);
       else STOTUNIT = input(compress(STOTUN,', '),8.);
    end;
  else STOTUNIT = -1;


****Convert SDWNHIA from character to numeric variables****;
****DWNHIA retains the original raw data in a character format****;

  if indexc(upcase(DWNHIA),"/+-ABCDEFGHIJKLMNOPQRSTUVWXYZ?<>")=0 then
    do;
       SDWNHIA = input(compress(DWNHIA,'~`,$'),32.);
    end;
  else 
    do;
       if substr(reverse(upcase(compress(DWNHIA))),1,1)='K' and indexc(upcase(DWNHIA),'-/')=0
         then SDWNHIA = 1000 * compress(DWNHIA,'Kk ');
       else SDWNHIA = -1;
    end;

****Convert SDWNLOWA from character to numeric variables****;
****DWNLOWA retains the original raw data in a character format****;
    
  if indexc(upcase(DWNLOWA),"/+-ABCDEFGHIJKLMNOPQRSTUVWXYZ?<>")=0 then
    do;
       SDWNLOWA = input(compress(DWNLOWA,'~`,$'),32.);
    end;
  else 
    do;
       if substr(reverse(upcase(compress(DWNLOWA))),1,1)='K' and indexc(upcase(DWNLOWA),'-/')=0
         then SDWNLOWA = 1000 * compress(DWNLOWA,'Kk ');
       else SDWNLOWA = -1;
    end;


****Convert SDWNHIP from character to numeric variables****;
****DWNHIP retains the original raw data in a character format****;

  if indexc(upcase(DWNHIP),"/+-ABCDEFGHIJKLMNOPQRSTUVWXYZ?<>")=0 then
    do;
       if compress(DWNHIP) in ('003','05') then SDWNHIP = input(compress(DWNHIP,'0 '),8.);
       else SDWNHIP = input(compress(DWNHIP,'~`% '),8.);
    end;
  else
    do;
       if index(DWNHIP,'1/4')>0 then SDWNHIP = 2.25;
       else SDWNHIP = -1;
    end;

****Convert SDWNLOWP from character to numeric variables****;
****DWNLOWP retains the original raw data in a character format****;
  
  if indexc(upcase(DWNLOWP),"/+-ABCDEFGHIJKLMNOPQRSTUVWXYZ?<>")=0 then
    do;
       if compress(DWNLOWP) in ('003','02') then SDWNLOWP = input(compress(DWNLOWP,'0 '),8.);
       else if compress(DWNLOWP)='1,5' then SDWNLOWP = 1.5;
       else SDWNLOWP = input(compress(DWNLOWP,'~`%'),8.);
    end;
  else
    do;
       if index(DWNLOWP,'1/2')>0 then SDWNLOWP = 0.5 + substr(compress(DWNLOWP),1,1);
       else SDWNLOWP = -1;
    end;

proc contents ;

run;

data hds.moresale ;
  set hds.moresale (
                 rename=(STOTUNIT=STOTUN 
                         SDWNHIA =DWNHIA
                         SDWNLOWA=DWNLOWA
                         SDWNHIP =DWNHIP
                         SDWNLOWP=DWNLOWP));
  length STOTUNIT 8. SDWNHIA 8. SDWNLOWA 8. SDWNHIP 8. SDWNLOWP 8. ;

  

****Conversts military to standard time****;
  if 12< SAPPT_H <=24 then do;
   SAPPT_H = SAPPT_H -12; 
   SAPPT_AM = 2;
   *put Control= testerid= 'Subtracted 12 from SAPPT_H';
  end;
  
  if 12< SBEGT_H <=24 then do;
   SBEGT_H = SBEGT_H -12; 
   SBEGT_AM = 2;
   *put Control= testerid= 'Subtracted 12 from SBEGT_H';
  end;
  
  if 12< SENDT_H <=24 then do;
   SENDT_H = SENDT_H -12; 
   SENDT_AM = 2;
   *put Control= testerid= 'Subtracted 12 from SENDT_H';
  end;
  
  if 12< STIME_H <=24 then do;
   STIME_H = STIME_H -12; 
   STIME_AM = 2;
   *put Control= testerid= 'Subtracted 12 from STIME_H';
  end;

****Sets test year to 2000****;
  if SDATE_Y not in (99,1999,1,2001) THEN SDATE_Y = 2000;


****Convert STOTUNIT from character to numeric variables****;
****STOTUN retains the original raw data in a character format****;

  if indexc(upcase(STOTUN),'/.+-ABCDEFGHIJKLMNOPQRSTUVWXYZ?$<>')=0 then
    do;
       if compress(STOTUN) in ('01','07','09') then STOTUNIT = input(compress(STOTUN,'0 '),8.);
       else STOTUNIT = input(compress(STOTUN,', '),8.);
    end;
  else STOTUNIT = -1;


****Convert SDWNHIA from character to numeric variables****;
****DWNHIA retains the original raw data in a character format****;

  if indexc(upcase(DWNHIA),"/+-ABCDEFGHIJKLMNOPQRSTUVWXYZ?<>")=0 then
    do;
       SDWNHIA = input(compress(DWNHIA,'~`,$'),32.);
    end;
  else 
    do;
       if substr(reverse(upcase(compress(DWNHIA))),1,1)='K' and indexc(upcase(DWNHIA),'-/')=0
         then SDWNHIA = 1000 * compress(DWNHIA,'Kk ');
       else SDWNHIA = -1;
    end;

****Convert SDWNLOWA from character to numeric variables****;
****DWNLOWA retains the original raw data in a character format****;
    
  if indexc(upcase(DWNLOWA),"/+-ABCDEFGHIJKLMNOPQRSTUVWXYZ?<>")=0 then
    do;
       SDWNLOWA = input(compress(DWNLOWA,'~`,$'),32.);
    end;
  else 
    do;
       if substr(reverse(upcase(compress(DWNLOWA))),1,1)='K' and indexc(upcase(DWNLOWA),'-/')=0
         then SDWNLOWA = 1000 * compress(DWNLOWA,'Kk ');
       else SDWNLOWA = -1;
    end;


****Convert SDWNHIP from character to numeric variables****;
****DWNHIP retains the original raw data in a character format****;

  if indexc(upcase(DWNHIP),"/+-ABCDEFGHIJKLMNOPQRSTUVWXYZ?<>")=0 then
    do;
       if compress(DWNHIP) in ('003','05') then SDWNHIP = input(compress(DWNHIP,'0 '),8.);
       else SDWNHIP = input(compress(DWNHIP,'~`% '),8.);
    end;
  else
    do;
       if index(DWNHIP,'1/4')>0 then SDWNHIP = 2.25;
       else SDWNHIP = -1;
    end;

****Convert SDWNLOWP from character to numeric variables****;
****DWNLOWP retains the original raw data in a character format****;
  
  if indexc(upcase(DWNLOWP),"/+-ABCDEFGHIJKLMNOPQRSTUVWXYZ?<>")=0 then
    do;
       if compress(DWNLOWP) in ('003','02') then SDWNLOWP = input(compress(DWNLOWP,'0 '),8.);
       else if compress(DWNLOWP)='1,5' then SDWNLOWP = 1.5;
       else SDWNLOWP = input(compress(DWNLOWP,'~`%'),8.);
    end;
  else
    do;
       if index(DWNLOWP,'1/2')>0 then SDWNLOWP = 0.5 + substr(compress(DWNLOWP),1,1);
       else SDWNLOWP = -1;
    end;


proc contents ;

run;
