****************************************************************
* Program name:  followup.sas
* Project:       Housing Discrimination Study Phase I
*
*  Final version: February 7, 2001 by Steve Ross
*
*  This program reads the follow-up contact logs and generates
*  a variable indicating whether that log represents evidence
*  of follow-up contact.  The logs are compileds by visit in
*  order to indicate whether a specific tester received follow-up
*  contact after their participation in a specific test.
*
* Input Files:   foluplog.ssd01
*
* Output Files:  follow.ssd01
*
*                                            
****************************************************************;
options nocenter ;

libname hds2000 '/mnt/jayhawk/jayproj/hds2000' ;
filename foluplog '/mnt/jayhawk/jayproj/hds2000/foluplog.ssd01' ;
filename follow '/mnt/jayhawk/jayproj/hds2000/follow.ssd01' ;

/* load data on followup contact */

data follow ;
  set hds2000.foluplog ;
  count=1 ;

/* fix testerid's */

  if control='CH-RH-1201' and testerid='WF17' then
     testerid='W-F-17' ;
  if control='CH-RH-1201' and testerid='hf02' then
     testerid='H-F-02' ;
  if control='CH-SB-2812' and testerid='CH-wm-lane' then
     testerid='WM-Lane' ;
  if control='CH-SB-3007' and testerid='W-F-17' then
     testerid='w-f-17' ;
  if control='CH-SH-0908' and testerid='H-F-10' then
     testerid='h-f-10' ;
  if control='CH-SH-1704' and testerid='H-M-05' then
     testerid='h-m-05' ;
  if control='CH-SH-1704' and testerid='W-M-06' then
     testerid='w-m-06' ;
  if control='CH-SH-1714' and testerid='W-M-03' then
     testerid='w-m-03' ;
  if control='CH-SH-1920' and testerid='W-F-04' then
     testerid='w-f-04' ;
  if control='CH-SH-1930' and testerid='H-M-05' then
     testerid='h-m-05' ;
  if control='CH-SH-2036' and testerid='H-F-04' then
     testerid='H-M-04' ;
  if control='CH-SH-2821' and testerid='W-F-17' then
     testerid='w-f-17' ;
  if control='CN-SB-2206' and testerid='WM-LANE' then
     testerid='WM-Lane' ;
  if control='DS-SB-0610' and testerid='12' then
     testerid='012' ;
  if control='DS-SB-0610' and testerid='5' then
     testerid='05' ;
  if control='DT-SB-1307' and testerid='DET' then
     testerid='DET 105' ;
  if control='DT-SB-1815' and testerid='DET-104' then
     testerid='det-104' ;
  if control='DT-SB-2101' and testerid='DET-133' then
     testerid='det-133' ;
  if control='MA-SB-1307' and testerid='38' then
     testerid='038' ;
  if control='MA-SB-1308' and testerid='032' then
     testerid='32' ;
  if control='MN-SS-0803' and testerid='w8' then
     testerid='W8' ;
  if control='NY-SB-0305' and testerid='34' then
     testerid='034' ;
  if control='NY-SB-0401' and testerid='34' then
     testerid='034' ;
  if control='NY-SB-0402' and testerid='026' then
     testerid='26' ;
  if control='PU-SH-0511' and testerid='11' then
     testerid='111' ;
  if control='SA-RH-0803' and testerid='Wandless' then
     testerid='100' ;
  if control='SD-SH-1724' and testerid='46' then
     testerid='55' ;
  if control='SD-SH-1724' and testerid='46' then
     testerid='55' ;
  if control='SD-SH-1724' and testerid='46' then
     testerid='55' ;
  if control='SD-SH-1724' and testerid='46' then
     testerid='55' ;


  if del_rec=1 or duplicat=1 or (lcontype=0 and lnocont=1) 
          then delete ;
    else output follow ;

/* look for duplicate observations */

proc sort data=follow ;
   by control testerid sequence ;
proc means data=follow noprint ;
   var count ;
   output out=mfollow sum=totcnt ;
   by control testerid sequence ;

data follow dup ;
  merge follow (in=q1) mfollow ;
   by control testerid sequence ;
  if q1 ;
  if totcnt>1 then output dup ;
    else output follow ;

/* delete duplicate observations */

data dup ;
  set dup ;
  if _N_ in (1, 3, 5, 7, 9, 13, 15, 17, 19,
             21, 23, 25, 27, 29, 31, 33, 35, 37, 39,
             41, 43, 45, 47, 49, 51, 53, 55, 57, 59,
             61, 63, 65, 67, 69, 71, 73, 75, 77, 79,
             81, 83, 85, 87, 89, 91, 93, 95, 97, 99,
             101, 103, 105, 107, 109, 111, 113, 115, 117, 119,
             121, 123, 125, 127, 129, 131, 133, 135, 137) 
         then output dup ;
  else delete ;

/* create contact variable based on premise that a filed form
implies follow-up contact unless contradicted by a positive statement
of no contact or a failure to provide a type of contact plus a
confirmation based on missing information on agency and contact
name */

data follow ;
  set follow dup ;
  count=1 ;
  if (lnocont=1 and lcontype^=0) or (lnocont=0 and lcontype=0)
    then do ;
    if (lconname='' or lconname='no follow up') and 
       (lagency='' or lagency='no follow up') then count=0  ;
    end ;

/* sum up number of forms indicating follow up contact for a
specific visit.  totcnt2>=1 implies that there was follow up
contact */

proc sort ;
  by control testerid ;
proc means noprint ;
   var count ;
   by control testerid ;
   output out=mfollow2 sum=totcnt2 ;


proc freq ;
  tables totcnt2 ;

/* save cleaned follow up visit sample */

data hds2000.follow ;
  set mfollow2 ;
  keep control testerid totcnt2 ;

data test ;
  set mfollow2 ;
  type=substr(control,4,1) ;

proc freq ;
  tables type ;
run;
	