****************************************************************
* Program name:  rental_metro.sas
* Project:       Housing Discrimination Study Phase I
*
*  Final version: March 15, 2002 by Steve Ross
*
*  This program uses data from the 2000 rental housing discrimination 
*  studies in order to generate metro level estimates of adverse 
*  treatment The results are found in table format in the sas list 
*  file, rental_metro.lst.
*  
* Input Files:   fnrntmrg.ssd01
*
* Output Files:  none
*                                            
****************************************************************;

options nocenter ;

libname hds '/mnt/jayhawk/jayproj/hds2000' ;

filename fnrntmrg '/mnt/jayhawk/jayproj/hds2000/fnrntmrg.ssd01' ;

data hds2000 ;
  set hds.fnrntmrg ;

  year='2000' ;
  type=substr(control,5,1) ;

/* delete observations that are not core */

  if site='AZ' then site='TC' ;

  if site='AN' or site='CN' or
   site='LN' or site='NN' or site='SN' or 
   site='AX' or site='CX' or site='LX' or
   site='NX' or site='SX' then delete ;
     else output hds2000 ; 


proc sort ; by type site ;

data bwtests ;
  set hds2000 ;

/* create treatement variables */

avail11=0 ; avail10=0 ; avail01=0 ; availc=1 ;
if wavailad=1 and mavailad=1 then avail11=1 ;
  else if wavailad=1 and mavailad=0 then avail10=1 ;
  else if wavailad=0 and mavailad=1 then avail01=1 ;

avlsm11=0 ; avlsm10=0 ; avlsm01=0 ; avlsmc=1 ;
if wavailsm=1 and mavailsm=1 then avlsm11=1 ;
  else if wavailsm=1 and mavailsm=0 then avlsm10=1 ;
  else if wavailsm=0 and mavailsm=1 then avlsm01=1 ;

recom11=0 ; recom10=0 ; recom01=0 ; recomc=1 ;
if wrecomi=1 and mrecomi=1 then recom11=1 ;
  else if wrecomi=1 and mrecomi=0 then recom10=1 ;
  else if wrecomi=0 and mrecomi=1 then recom01=1 ;


waccess=0 ; maccess=0 ; 
if avail10=1 then waccess=1 ;
  else if avail01=1 then maccess=1 ;
  else if avlsm10=1 then waccess=1 ;
  else if avlsm01=1 then maccess=1 ;
  else if recom10=1 then waccess=1 ;
  else if recom01=1 then maccess=1 ;


wacccns=0 ; macccns=0 ; 
if (avail10=1 or avlsm10=1 or recom10=1) then wacccns=1 ;
if (avail01=1 or avlsm01=1 or recom01=1) then macccns=1 ;

  
inspad11=0 ; inspad10=0 ; inspad01=0 ; inspadc=1 ;
if winspadv=1 and minspadv=1 then inspad11=1 ;
  else if winspadv=1 and minspadv=0 then inspad10=1 ;
  else if winspadv=0 and minspadv=1 then inspad01=1 ;

inspsm11=0 ; inspsm10=0 ; inspsm01=0 ; inspsmc=1 ;
if winspsim=1 and minspsim=1 then inspsm11=1 ;
  else if winspsim=1 and minspsim=0 then inspsm10=1 ;
  else if winspsim=0 and minspsim=1 then inspsm01=1 ;

inspct11=0 ; inspct10=0 ; inspct01=0 ; inspctc=1 ;
if winspcti=1 and minspcti=1 then inspct11=1 ;
  else if winspcti=1 and minspcti=0 then inspct10=1 ;
  else if winspcti=0 and minspcti=1 then inspct01=1 ;

waccss2=0 ; maccss2=0 ;
if inspad10=1 then waccss2=1 ;
else if inspad01=1 then maccss2=1 ;
else if inspsm10=1 then waccss2=1 ;
else if inspsm01=1 then maccss2=1 ;
else if inspct10=1 then waccss2=1 ;
else if inspct01=1 then maccss2=1 ;

wacc2cns=0 ; macc2cns=0 ;
if (inspad10=1 or inspsm10=1 or inspct10=1) then wacc2cns=1 ;
if (inspad01=1 or inspsm01=1 or inspct01=1) then macc2cns=1 ;


askfil11=0 ; askfil10=0 ; askfil01=0 ; askfilc=1 ;
if waskfill=1 and maskfill=1 then askfil11=1 ;
  else if waskfill=1 and maskfill=0 then askfil10=1 ;
  else if waskfill=0 and maskfill=1 then askfil01=1 ;

callbk11=0 ; callbk10=0 ; callbk01=0 ; callbkc=1 ;
if wcallbak=1 and mcallbak=1 then callbk11=1 ;
  else if wcallbak=1 and mcallbak=0 then callbk10=1 ;
  else if wcallbak=0 and mcallbak=1 then callbk01=1 ;

sugdif11=0 ; sugdif10=0 ; sugdif01=0 ; sugdifc=1 ;
if wsugdiff=1 and msugdiff=1 then sugdif11=1 ;
  else if wsugdiff=1 and msugdiff=0 then sugdif10=1 ;
  else if wsugdiff=0 and msugdiff=1 then sugdif01=1 ;

waitl11=0 ; waitl10=0 ; waitl01=0 ; waitlc=1 ;
if wwaitlst=1 and mwaitlst=1 then waitl11=1 ;
  else if wwaitlst=1 and mwaitlst=0 then waitl10=1 ;
  else if wwaitlst=0 and mwaitlst=1 then waitl01=1 ;

nofutc11=0 ; nofutc10=0 ; nofutc01=0 ; nofutcc=1 ;
if wnofutcn=1 and mnofutcn=1 then nofutc11=1 ;
  else if wnofutcn=1 and mnofutcn=0 then nofutc01=1 ;
  else if wnofutcn=0 and mnofutcn=1 then nofutc10=1 ;

follow11=0 ; follow10=0 ; follow01=0 ; followc=1 ;
if wfollow=1 and mfollow=1 then follow11=1 ;
  else if wfollow=1 and mfollow=0 then follow10=1 ;
  else if wfollow=0 and mfollow=1 then follow01=1 ;

qual11=0 ; qual10=0 ; qual01=0 ; qualc=1 ;
if wqual=1 and mqual=1 then qual11=1 ;
  else if wqual=1 and mqual=0 then qual10=1 ;
  else if wqual=0 and mqual=1 then qual01=1 ;


meettm11=0 ; meettm10=0 ; meettm01=0 ; meettmc=1 ;
if wmeettmi=1 and mmeettmi=1 then meettm11=1 ;
  else if wmeettmi=1 and mmeettmi=0 then meettm10=1 ;
  else if wmeettmi=0 and mmeettmi=1 then meettm01=1 ;
  else if wmeettmi=. or mmeettmi=. then do ;
     meettm11=. ; meettm10=. ; meettm01=. ; meettmc=. ;
     end ;


mservice=0 ; wservice=0 ;
if follow10=1 then wservice=1 ;
  else if follow01=1 then mservice=1 ;
  else if askfil10=1 then wservice=1 ;
  else if askfil01=1 then mservice=1 ;
  else if nofutc10=1 then wservice=1 ;
  else if nofutc01=1 then mservice=1 ;
  else if qual10=1 then wservice=1 ;
  else if qual01=1 then mservice=1 ;



mservcns=0 ; wservcns=0 ;
if (follow10=1 or askfil10=1 or nofutc10=1 or qual10=1)
   then wservcns=1 ;
if (follow01=1 or askfil01=1 or nofutc01=1 or qual01=1)
   then mservcns=1 ;



appfee11=0 ; appfee10=0 ; appfee01=0 ; appfeec=1 ;
if wappfee=1 and mappfee=1 then appfee11=1 ;
  else if wappfee=1 and mappfee=0 then appfee01=1 ;
  else if wappfee=0 and mappfee=1 then appfee10=1 ;
  else if wappfee=. or mappfee=. then do ;
     appfee11=. ; appfee10=. ; appfee01=. ; appfeec=. ;
     end ;

incent11=0 ; incent10=0 ; incent01=0 ; incentc=1 ;
if wincent=1 and mincent=1 then incent11=1 ;
  else if wincent=1 and mincent=0 then incent10=1 ;
  else if wincent=0 and mincent=1 then incent01=1 ;

heat11=0 ; heat10=0 ; heat01=0 ; heatc=1 ;
if wadvheat=1 and madvheat=1 then heat11=1 ;
  else if wadvheat=1 and madvheat=0 then heat10=1 ;
  else if wadvheat=0 and madvheat=1 then heat01=1 ;
  else if wadvheat=. or madvheat=. then do ;
       heat11=. ; heat01=. ; heat01=. ; heatc=. ;
       end ;

rentad11=0 ; rentad10=0 ; rentad01=0; rentadc=1 ;
if wrentadi=1 and mrentadi=1 then rentad11=1 ;
  else if wrentadi=1 and mrentadi=0 then rentad01=1 ;
  else if wrentadi=0 and mrentadi=1 then rentad10=1 ;
  else if wrentadi=. or mrentadi=. then do ;
     rentad11=. ; rentad10=. ; rentad01=.; rentadc=. ;
     end ;

secdep11=0 ; secdep10=0 ; secdep01=0 ; secdepc=1 ;
if wsecdepi=1 and msecdepi=1 then secdep11=1 ;
  else if wsecdepi=1 and msecdepi=0 then secdep01=1 ;
  else if wsecdepi=0 and msecdepi=1 then secdep10=1 ;
  else if wsecdepi=. or msecdepi=. then do ;
     secdep11=. ; secdep10=. ; secdep01=. ; secdepc=. ;
     end ;


mterms=0 ; wterms=0 ;
if rentad10=1 then wterms=1 ;
  else if rentad01=1 then mterms=1 ;
  else if incent10=1 then wterms=1 ;
  else if incent01=1 then mterms=1 ;
  else if secdep10=1 then wterms=1 ;
  else if secdep01=1 then mterms=1 ;
  else if appfee10=1 then wterms=1 ;
  else if appfee01=1 then mterms=1 ;


mtrmcns=0 ; wtrmcns=0 ;
if (rentad10=1 or incent10=1 or secdep10=1 or appfee10=1) then wtrmcns=1 ;
if (rentad01=1 or incent01=1 or secdep01=1 or appfee01=1) then mtrmcns=1 ;


access11=0 ; access10=0 ; access01=0 ; accessc=1 ;
if waccess=1 and maccess=1 then access11=1 ;
if waccess=1 and maccess=0 then access10=1 ;
if waccess=0 and maccess=1 then access01=1 ;

accss211=0 ; accss210=0 ; accss201=0 ; accss2c=1 ;
if waccss2=1 and maccss2=1 then accss211=1 ;
if waccss2=1 and maccss2=0 then accss210=1 ;
if waccss2=0 and maccss2=1 then accss201=1 ;

servic11=0 ; servic10=0 ; servic01=0 ; servicc=1 ;
if wservice=1 and mservice=1 then servic11=1 ;
if wservice=1 and mservice=0 then servic10=1 ;
if wservice=0 and mservice=1 then servic01=1 ;

terms11=0 ; terms10=0 ; terms01=0 ; termsc=1 ;
if wterms=1 and mterms=1 then terms11=1 ; 
if wterms=1 and mterms=0 then terms10=1 ; 
if wterms=0 and mterms=1 then terms01=1 ; 


acccns11=0 ; acccns10=0 ; acccns01=0 ; acccnsc=1 ;
if wacccns=1 and macccns=1 then acccns11=1 ;
else if wacccns=1 and macccns=0 then acccns10=1 ;
else if wacccns=0 and macccns=1 then acccns01=1 ;

ac2cns11=0 ; ac2cns10=0 ; ac2cns01=0 ; ac2cnsc=1 ;
if wacc2cns=1 and macc2cns=1 then ac2cns11=1 ;
else if wacc2cns=1 and macc2cns=0 then ac2cns10=1 ;
else if wacc2cns=0 and macc2cns=1 then ac2cns01=1 ;

srvcns11=0 ; srvcns10=0 ; srvcns01=0 ; srvcnsc=1 ;
if wservcns=1 and mservcns=1 then srvcns11=1 ;
else if wservcns=1 and mservcns=0 then srvcns10=1 ;
else if wservcns=0 and mservcns=1 then srvcns01=1 ;

trmcns11=0 ; trmcns10=0 ; trmcns01=0 ; trmcnsc=1 ;
if wtrmcns=1 and mtrmcns=1 then trmcns11=1 ; 
else if wtrmcns=1 and mtrmcns=0 then trmcns10=1 ; 
else if wtrmcns=0 and mtrmcns=1 then trmcns01=1 ; 

cnsty11=0 ; cnsty10=0 ; cnsty01=0 ; cnstyc=1 ;
if (mtrmcns=1 or  mservcns=1 or macccns=1 or macc2cns=1) and
   (wtrmcns=1 or wservcns=1 or wacccns=1 or wacc2cns=1)
   then cnsty11=1 ;
else if (wtrmcns=1 or wservcns=1 or wacccns=1 or wacc2cns=1) and
   mtrmcns=0 and mservcns=0 and macccns=0 and macc2cns=0
   then cnsty10=1 ;
else if (mtrmcns=1 or mservcns=1 or macccns=1 or macc2cns=1) and
   wtrmcns=0 and wservcns=0 and wacccns=0 and wacc2cns=0
   then cnsty01=1 ;

/* create heirarchy composite variables */

wheir1=0 ;
wheir2=0 ;
wheir3=0 ;
wheir4=0 ;
wheir5=0 ;
wheir6=0 ;
wheir7=0 ;
wheir8=0 ;
wheir9=0 ;
wheir10=0 ;
wheir11=0 ;
wheir12=0 ;
wheir13=0 ;
wheir14=0 ;
mheir1=0 ;
mheir2=0 ;
mheir3=0 ;
mheir4=0 ;
mheir5=0 ;
mheir6=0 ;
mheir7=0 ;
mheir8=0 ;
mheir9=0 ;
mheir10=0 ;
mheir11=0 ;
mheir12=0 ;
mheir13=0 ;
mheir14=0 ;
if avail10=1 then do ; 
  wheir1=1 ;
  wheir2=1 ;
  wheir3=1 ;
  wheir4=1 ;
  wheir5=1 ;
  wheir6=1 ;
  wheir7=1 ;
  wheir8=1 ;
  wheir9=1 ;
  wheir10=1 ;
  wheir11=1 ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if avail01=1 then do ;
  mheir1=1 ;
  mheir2=1 ;
  mheir3=1 ;
  mheir4=1 ;
  mheir5=1 ;
  mheir6=1 ;
  mheir7=1 ;
  mheir8=1 ;
  mheir9=1 ;
  mheir10=1 ;
  mheir11=1 ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if inspad10=1 then do ;
  wheir2=1 ;
  wheir3=1 ;
  wheir4=1 ;
  wheir5=1 ;
  wheir6=1 ;
  wheir7=1 ;
  wheir8=1 ;
  wheir9=1 ;
  wheir10=1 ;
  wheir11=1 ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if inspad01=1 then do ;
  mheir2=1 ;
  mheir3=1 ;
  mheir4=1 ;
  mheir5=1 ;
  mheir6=1 ;
  mheir7=1 ;
  mheir8=1 ;
  mheir9=1 ;
  mheir10=1 ;
  mheir11=1 ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if rentad10=1 then do ;
  wheir3=1 ;
  wheir4=1 ;
  wheir5=1 ;
  wheir6=1 ;
  wheir7=1 ;
  wheir8=1 ;
  wheir9=1 ;
  wheir10=1 ;
  wheir11=1 ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if rentad01=1 then do ;
  mheir3=1 ;
  mheir4=1 ;
  mheir5=1 ;
  mheir6=1 ;
  mheir7=1 ;
  mheir8=1 ;
  mheir9=1 ;
  mheir10=1 ;
  mheir11=1 ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if avlsm10=1 then  do ;
  wheir4=1 ;
  wheir5=1 ;
  wheir6=1 ;
  wheir7=1 ;
  wheir8=1 ;
  wheir9=1 ;
  wheir10=1 ;
  wheir11=1 ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if avlsm01=1 then  do ;
  mheir4=1 ;
  mheir5=1 ;
  mheir6=1 ;
  mheir7=1 ;
  mheir8=1 ;
  mheir9=1 ;
  mheir10=1 ;
  mheir11=1 ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if inspsm10=1 then do ;
  wheir5=1 ;
  wheir6=1 ;
  wheir7=1 ;
  wheir8=1 ;
  wheir9=1 ;
  wheir10=1 ;
  wheir11=1 ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if inspsm01=1 then do ;
  mheir5=1 ;
  mheir6=1 ;
  mheir7=1 ;
  mheir8=1 ;
  mheir9=1 ;
  mheir10=1 ;
  mheir11=1 ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if recom10=1 then  do ;
  wheir6=1 ;
  wheir7=1 ;
  wheir8=1 ;
  wheir9=1 ;
  wheir10=1 ;
  wheir11=1 ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if recom01=1 then  do ;
  mheir6=1 ;
  mheir7=1 ;
  mheir8=1 ;
  mheir9=1 ;
  mheir10=1 ;
  mheir11=1 ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if inspct10=1 then do ;
  wheir7=1 ;
  wheir8=1 ;
  wheir9=1 ;
  wheir10=1 ;
  wheir11=1 ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if inspct01=1 then do ;
  mheir7=1 ;
  mheir8=1 ;
  mheir9=1 ;
  mheir10=1 ;
  mheir11=1 ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if incent10=1 then do ;
  wheir8=1 ;
  wheir9=1 ;
  wheir10=1 ;
  wheir11=1 ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if incent01=1 then do ;
  mheir8=1 ;
  mheir9=1 ;
  mheir10=1 ;
  mheir11=1 ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if secdep10=1 then do ;
  wheir9=1 ;
  wheir10=1 ;
  wheir11=1 ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if secdep01=1 then do ;
  mheir9=1 ;
  mheir10=1 ;
  mheir11=1 ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if appfee10=1 then do ;
  wheir10=1 ;
  wheir11=1 ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if appfee01=1 then do ;
  mheir10=1 ;
  mheir11=1 ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if follow10=1 then do ;
  wheir11=1 ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if follow01=1 then do ;
  mheir11=1 ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if askfil10=1 then do ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if askfil01=1 then do ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if nofutc10=1 then do ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if nofutc01=1 then do ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if qual10=1 then  do ;
  wheir14=1 ;
  end ;
  else if qual01=1 then  do ;
  mheir14=1 ;
  end ;



hr1q11=0 ; hr1q10=0 ; hr1q01=0 ; hr1qc=1 ;
if wheir1=1 and mheir1=1 then hr1q11=1 ; 
if wheir1=1 and mheir1=0 then hr1q10=1 ; 
if wheir1=0 and mheir1=1 then hr1q01=1 ; 


hr2q11=0 ; hr2q10=0 ; hr2q01=0 ; hr2qc=1 ;
if wheir2=1 and mheir2=1 then hr2q11=1 ; 
if wheir2=1 and mheir2=0 then hr2q10=1 ; 
if wheir2=0 and mheir2=1 then hr2q01=1 ; 


hr3q11=0 ; hr3q10=0 ; hr3q01=0 ; hr3qc=1 ;
if wheir3=1 and mheir3=1 then hr3q11=1 ; 
if wheir3=1 and mheir3=0 then hr3q10=1 ; 
if wheir3=0 and mheir3=1 then hr3q01=1 ; 


hr4q11=0 ; hr4q10=0 ; hr4q01=0 ; hr4qc=1 ;
if wheir4=1 and mheir4=1 then hr4q11=1 ; 
if wheir4=1 and mheir4=0 then hr4q10=1 ; 
if wheir4=0 and mheir4=1 then hr4q01=1 ; 


hr5q11=0 ; hr5q10=0 ; hr5q01=0 ; hr5qc=1 ;
if wheir5=1 and mheir5=1 then hr5q11=1 ; 
if wheir5=1 and mheir5=0 then hr5q10=1 ; 
if wheir5=0 and mheir5=1 then hr5q01=1 ; 


hr6q11=0 ; hr6q10=0 ; hr6q01=0 ; hr6qc=1 ;
if wheir6=1 and mheir6=1 then hr6q11=1 ; 
if wheir6=1 and mheir6=0 then hr6q10=1 ; 
if wheir6=0 and mheir6=1 then hr6q01=1 ; 


hr7q11=0 ; hr7q10=0 ; hr7q01=0 ; hr7qc=1 ;
if wheir7=1 and mheir7=1 then hr7q11=1 ; 
if wheir7=1 and mheir7=0 then hr7q10=1 ; 
if wheir7=0 and mheir7=1 then hr7q01=1 ; 


hr8q11=0 ; hr8q10=0 ; hr8q01=0 ; hr8qc=1 ;
if wheir8=1 and mheir8=1 then hr8q11=1 ; 
if wheir8=1 and mheir8=0 then hr8q10=1 ; 
if wheir8=0 and mheir8=1 then hr8q01=1 ; 


hr9q11=0 ; hr9q10=0 ; hr9q01=0 ; hr9qc=1 ;
if wheir9=1 and mheir9=1 then hr9q11=1 ; 
if wheir9=1 and mheir9=0 then hr9q10=1 ; 
if wheir9=0 and mheir9=1 then hr9q01=1 ; 


hr10q11=0 ; hr10q10=0 ; hr10q01=0 ; hr10qc=1 ;
if wheir10=1 and mheir10=1 then hr10q11=1 ; 
if wheir10=1 and mheir10=0 then hr10q10=1 ; 
if wheir10=0 and mheir10=1 then hr10q01=1 ; 


hr11q11=0 ; hr11q10=0 ; hr11q01=0 ; hr11qc=1 ;
if wheir11=1 and mheir11=1 then hr11q11=1 ; 
if wheir11=1 and mheir11=0 then hr11q10=1 ; 
if wheir11=0 and mheir11=1 then hr11q01=1 ; 


hr12q11=0 ; hr12q10=0 ; hr12q01=0 ; hr12qc=1 ;
if wheir12=1 and mheir12=1 then hr12q11=1 ; 
if wheir12=1 and mheir12=0 then hr12q10=1 ; 
if wheir12=0 and mheir12=1 then hr12q01=1 ; 

hr13q11=0 ; hr13q10=0 ; hr13q01=0 ; hr13qc=1 ;
if wheir13=1 and mheir13=1 then hr13q11=1 ; 
if wheir13=1 and mheir13=0 then hr13q10=1 ; 
if wheir13=0 and mheir13=1 then hr13q01=1 ; 

hr14q11=0 ; hr14q10=0 ; hr14q01=0 ; hr14qc=1 ;
if wheir14=1 and mheir14=1 then hr14q11=1 ; 
if wheir14=1 and mheir14=0 then hr14q10=1 ; 
if wheir14=0 and mheir14=1 then hr14q01=1 ; 

/* create sample of outcomes for each treatment variable where
the sample covers all sites and types of tests. */

proc means noprint data=bwtests ; 
   var avail11 avail10 avail01 availc ;
      by type site ;
   output out=avail mean=equal white black sum=c11 c10 c01 valid ;


data avail ;
  set avail ;
  variable='availadv' ;
  count=1 ;

proc means noprint  data=bwtests ; 
   var avlsm11 avlsm10 avlsm01  avlsmc ;
      by type site ;
   output out=avlsm mean=equal white black sum=c11 c10 c01 valid ;



data avlsm ;
  set avlsm ;
  variable='availsim' ;
  count=2 ;

proc means noprint  data=bwtests ; 
   var recom11 recom10 recom01 recomc ;
      by type site ;
   output out=recom mean=equal white black  sum=c11 c10 c01 valid ;


data recom ;
  set recom ;
  variable='recom' ;
  count=3 ;

proc means noprint  data=bwtests ; 
   var access11 access10 access01 accessc ;
      by type site ;
   output out=access mean=equal white black  sum=c11 c10 c01 valid ;


data access ;
  set access ;
  variable='access' ;
  count=4 ;

proc means noprint  data=bwtests ; 
   var acccns11 acccns10 acccns01 acccnsc ;
      by type site ;
   output out=acccns mean=equal white black  sum=c11 c10 c01 valid ;


data acccns ;
  set acccns ;
  variable='acccns' ;
  count=5 ;



proc means noprint  data=bwtests ; 
   var inspad11 inspad10 inspad01 inspadc ;
      by type site ;
   output out=inspad mean=equal white black sum=c11 c10 c01 valid ;



data inspad ;
  set inspad ;
  variable='inspad' ;
  count=6 ;

proc means noprint  data=bwtests ; 
   var inspsm11 inspsm10 inspsm01 inspsmc ;
      by type site ;
   output out=inspsm mean=equal white black  sum=c11 c10 c01 valid ;


data inspsm ;
  set inspsm ;
  variable='inspsm' ;
  count=7 ;

proc means noprint  data=bwtests ; 
   var inspct11 inspct10 inspct01 inspctc ;
      by type site ;
   output out=inspct mean=equal white black  sum=c11 c10 c01 valid ;


data inspct ;
  set inspct ;
  variable='inspect' ;
  count=8 ;

proc means noprint  data=bwtests ; 
   var accss211 accss210 accss201 accss2c ;
      by type site ;
   output out=access2 mean=equal white black  sum=c11 c10 c01 valid ;


data access2 ;
  set access2 ;
  variable='access2' ;
  count=9 ;


proc means noprint  data=bwtests ; 
   var ac2cns11 ac2cns10 ac2cns01 ac2cnsc ;
      by type site ;
   output out=acc2cns mean=equal white black  sum=c11 c10 c01 valid ;


data acc2cns ;
  set acc2cns ;
  variable='acc2cns' ;
  count=10 ;

proc means noprint  data=bwtests ; 
   var rentad11 rentad10 rentad01 rentadc ;
      by type site ;
   output out=rentad mean=equal white black sum=c11 c10 c01 valid ;


data rentad ;
  set rentad ;
  variable='rentad' ;
  count=11 ;


proc means noprint  data=bwtests ; 
   var incent11 incent10 incent01 incentc ;
      by type site ;
   output out=incent mean=equal white black sum=c11 c10 c01 valid ;



data incent ;
  set incent ;
  variable='incent' ;
  count=12 ;



proc means noprint  data=bwtests ; 
   var secdep11 secdep10 secdep01 secdepc ;
      by type site ;
   output out=secdep mean=equal white black sum=c11 c10 c01 valid ;



data secdep ;
  set secdep ;
  variable='secdep' ;
  count=13 ;

proc means noprint  data=bwtests ; 
   var appfee11 appfee10 appfee01 appfeec ;
      by type site ;
   output out=appfee mean=equal white black sum=c11 c10 c01 valid ;


data appfee ;
  set appfee ;
  variable='appfee' ;
  count=14 ;


proc means noprint  data=bwtests ; 
   var terms11 terms10 terms01 termsc ;
      by type site ;
   output out=terms mean=equal white black sum=c11 c10 c01 valid ;



data terms ;
  set terms ;
  variable='terms' ;
  count=15 ;


proc means noprint  data=bwtests ; 
   var trmcns11 trmcns10 trmcns01 trmcnsc ;
      by type site ;
   output out=trmcns mean=equal white black sum=c11 c10 c01 valid ;



data trmcns ;
  set trmcns ;
  variable='trmcns' ;
  count=16 ;



proc means noprint  data=bwtests ; 
   var follow11 follow10 follow01 followc ;
      by type site ;
   output out=follow mean=equal white black sum=c11 c10 c01 valid  ;



data follow ;
  set follow ;
  variable='follow' ;
  count=17 ;



proc means noprint  data=bwtests ; 
   var askfil11 askfil10 askfil01 askfilc ;
      by type site ;
   output out=askfil mean=equal white black sum=c11 c10 c01 valid ;



data askfil ;
  set askfil ;
  variable='askfill' ;
  count=18 ;


proc means noprint  data=bwtests ; 
   var nofutc11 nofutc10 nofutc01 nofutcc;
      by type site ;
   output out=nofutcon mean=equal white black  sum=c11 c10 c01 valid ;



data nofutcon ;
  set nofutcon ;
  variable='nofutcon' ;
  count=19 ;



proc means noprint  data=bwtests ; 
   var qual11 qual10 qual01 qualc ;
      by type site ;
   output out=qual mean=equal white black sum=c11 c10 c01 valid  ;



data qual ;
  set qual ;
  variable='qual' ;
  count=20 ;


proc means noprint  data=bwtests ; 
   var servic11 servic10 servic01 servicc ;
      by type site ;
   output out=servic mean=equal white black sum=c11 c10 c01 valid  ;



data servic ;
  set servic ;
  variable='service' ;
  count=21 ;



proc means noprint  data=bwtests ; 
   var srvcns11 srvcns10 srvcns01 srvcnsc ;
      by type site ;
   output out=servcns mean=equal white black sum=c11 c10 c01 valid  ;



data servcns ;
  set servcns ;
  variable='servcns' ;
  count=22 ;

data avail2 ;
  set avail ;
  variable='availadv' ;
  count=23 ;

data inspad2 ;
  set inspad ;
  variable='inspad' ;
  count=24 ;


data rentad2 ;
  set rentad ;
  variable='rentad' ;
  count=25 ;

data avlsm2 ;
  set avlsm ;
  variable='availsim' ;
  count=26 ;

data inspsm2 ;
  set inspsm ;
  variable='inspsm' ;
  count=27 ;

data recom2 ;
  set recom ;
  variable='recom' ;
  count=28 ;

data inspct2 ;
  set inspct ;
  variable='inspect' ;
  count=29 ;

data incent2 ;
  set incent ;
  variable='incent' ;
  count=30 ;

data secdep2 ;
  set secdep ;
  variable='secdep' ;
  count=31 ;

data appfee2 ;
  set appfee ;
  variable='appfee' ;
  count=32 ;


data follow2 ;
  set follow ;
  variable='follow' ;
  count=33 ;

data askfil2 ;
  set askfil ;
  variable='askfill' ;
  count=34 ;

data nofutco2 ;
  set nofutcon ;
  variable='nofutcon' ;
  count=35 ;

data qual2 ;
  set qual ;
  variable='qual' ;
  count=36 ;


proc means noprint  data=bwtests ; 
   var hr1q11 hr1q10 hr1q01 hr1qc ;
      by type site ;
   output out=heir1 mean=equal white black sum=c11 c10 c01 valid  ;



data heir1 ;
  set heir1 ;
  variable='heir1' ;
  count=37 ;


proc means noprint  data=bwtests ; 
   var hr2q11 hr2q10 hr2q01 hr2qc ;
      by type site ;
   output out=heir2 mean=equal white black sum=c11 c10 c01 valid  ;



data heir2 ;
  set heir2 ;
  variable='heir2' ;
  count=38 ;


proc means noprint  data=bwtests ; 
   var hr3q11 hr3q10 hr3q01 hr3qc ;
      by type site ;
   output out=heir3 mean=equal white black sum=c11 c10 c01 valid  ;



data heir3 ;
  set heir3 ;
  variable='heir3' ;
  count=39 ;


proc means noprint  data=bwtests ; 
   var hr4q11 hr4q10 hr4q01 hr4qc ;
      by type site ;
   output out=heir4 mean=equal white black sum=c11 c10 c01 valid  ;



data heir4 ;
  set heir4 ;
  variable='heir4' ;
  count=40 ;


proc means noprint  data=bwtests ; 
   var hr5q11 hr5q10 hr5q01 hr5qc ;
      by type site ;
   output out=heir5 mean=equal white black sum=c11 c10 c01 valid  ;



data heir5 ;
  set heir5 ;
  variable='heir5' ;
  count=41 ;


proc means noprint  data=bwtests ; 
   var hr6q11 hr6q10 hr6q01 hr6qc ;
      by type site ;
   output out=heir6 mean=equal white black sum=c11 c10 c01 valid  ;



data heir6 ;
  set heir6 ;
  variable='heir6' ;
  count=42 ;


proc means noprint  data=bwtests ; 
   var hr7q11 hr7q10 hr7q01 hr7qc ;
      by type site ;
   output out=heir7 mean=equal white black sum=c11 c10 c01 valid  ;



data heir7 ;
  set heir7 ;
  variable='heir7' ;
  count=43 ;


proc means noprint  data=bwtests ; 
   var hr8q11 hr8q10 hr8q01 hr8qc ;
      by type site ;
   output out=heir8 mean=equal white black sum=c11 c10 c01 valid  ;



data heir8 ;
  set heir8 ;
  variable='heir8' ;
  count=44 ;


proc means noprint  data=bwtests ; 
   var hr9q11 hr9q10 hr9q01 hr9qc ;
      by type site ;
   output out=heir9 mean=equal white black sum=c11 c10 c01 valid  ;



data heir9 ;
  set heir9 ;
  variable='heir9' ;
  count=45 ;


proc means noprint  data=bwtests ; 
   var hr10q11 hr10q10 hr10q01 hr10qc ;
      by type site ;
   output out=heir10 mean=equal white black sum=c11 c10 c01 valid  ;



data heir10 ;
  set heir10 ;
  variable='heir10' ;
  count=46 ;


proc means noprint  data=bwtests ; 
   var hr11q11 hr11q10 hr11q01 hr11qc ;
      by type site ;
   output out=heir11 mean=equal white black sum=c11 c10 c01 valid  ;



data heir11 ;
  set heir11 ;
  variable='heir11' ;
  count=47 ;


proc means noprint  data=bwtests ; 
   var hr12q11 hr12q10 hr12q01 hr12qc ;
      by type site ;
   output out=heir12 mean=equal white black sum=c11 c10 c01 valid  ;



data heir12 ;
  set heir12 ;
  variable='heir12' ;
  count=48 ;


proc means noprint  data=bwtests ; 
   var hr13q11 hr13q10 hr13q01 hr13qc ;
      by type site ;
   output out=heir13 mean=equal white black sum=c11 c10 c01 valid  ;



data heir13 ;
  set heir13 ;
  variable='heir13' ;
  count=49 ;


proc means noprint  data=bwtests ; 
   var hr14q11 hr14q10 hr14q01 hr14qc ;
      by type site ;
   output out=heir14 mean=equal white black sum=c11 c10 c01 valid  ;



data heir14 ;
  set heir14 ;
  variable='heir14' ;
  count=50 ;

data heirfin ;
  set heir14 ;
  variable='heirfin' ;
  count=51 ;



proc means noprint  data=bwtests ; 
   var cnsty11 cnsty10 cnsty01 cnstyc ;
      by type site ;
   output out=cnsty mean=equal white black sum=c11 c10 c01 valid  ;



data cnsty ;
  set cnsty ;
  variable='cnsty' ;
  count=52 ;

/* create gross and net measures along with standard errors */

data bwstat ;
  set avail avlsm recom access acccns
      inspad inspsm inspct access2 acc2cns
      rentad secdep incent appfee terms trmcns
      askfil follow qual nofutcon servic servcns 
      cnsty heirfin ;
  net=white-black ;
  probw=equal+white ;
  probb=equal+black ;
  if valid=. or valid=0 then var=. ;
    else var=(probw*(1-probw) + probb*(1-probb) - 2 * (equal * ( 1 -
   equal - white - black) - white*black) ) / valid ;
  sd=var**0.5 ;
  if sd=. or sd=0 then tstat=. ;
     else tstat=net/sd ;
  keep type site variable white black net valid count ;

proc sort ;
  by type site count ;

data bwstat ;
  set bwstat ;
  keep type site variable white black net valid ;

/* output results */

proc print ;



run ;











