****************************************************************
* Program name:  rental_units.sas
* Author:        Steve Ross
* Final Version: February 7, 2001
* Project:       Housing Discrimination Study (#06977-000-00)
*
* This program reads the raw data from the question 17 of the 
* rental site visit report form.  This data is cleaned and
* merged with the information on tester needs from the paired
* assignment sample.  The final sample of rental housing units
* is merged with census tract characteristics that are provided
* by the Urban Institute.
* 
* Input Files:	q17.ssd01, fassign2.ssd01, runitdem.ssd01
* 
* Output Files:	q17nodup.ssd01 
*
****************************************************************;

options nocenter ;

libname hds2000 '/mnt/jayhawk/jayproj/hds2000' ;

filename fassign2 '/mnt/jayhawk/jayproj/hds2000/fassign2.ssd01' ;
filename q17 '/mnt/jayhawk/jayproj/hds2000/q17.ssd01' ;
filename q17nodup '/mnt/jayhawk/jayproj/hds2000/q17nodup.ssd01' ;
filename runitdem '/mnt/jayhawk/jayproj/hds2000/runitdem.ssd01' ;

/* load information on rental units recommended or inspected */

data q17 ;
  set hds2000.q17 ;
   revid=reverse(testerid) ;
   revid=compress(revid) ;
   count=1 ;

/* fix tester id's that have been manually verified by comparison 
with other q17 forms or with rental site visit report forms using
both the variable TESTERID and TESTER as a basis for comparison  */

   if control='AU-RB-1406' and testerid='1414' then testerid='01414';
   if control='AU-RH-0711' and testerid='02-129' then testerid='02209' ;
   if control='AZ-RN-1504' and testerid='O1P' then testerid='o1p' ;
   if control='CH-RB-0811' and testerid='I B-F' then testerid='BF-TAYL' ;
   if control='CH-RH-0702' and testerid='WM-Morr' then testerid='WM-MORR' ;
   if control='CH-RH-0707' and testerid='HM' then testerid='Hm-SANCH' ;
   if control='CH-RH-1201' and testerid='WF17' then testerid='W-F-17' ;
   if control='CH-RH-1201' and testerid='hf02' then testerid='H-F-02' ;
   if control='CH-RH-1441' and testerid='HF' then testerid='HF AQUI' ;
   if control='CH-RH-1441' and testerid='WF' then testerid='WF Isen' ;
   if control='CH-RH-1723' and testerid='HM-Sanc' then testerid='HM-SANC' ;
   if control='CH-RH-1723' and testerid='WM-Garn' then testerid='WM-GARN' ;
   if control='CH-RH-1723' and testerid='hm.sanc' then testerid='HM-SANC' ;
   if control='CH-RH-1723' and testerid='wm.garn' then testerid='WM-GARN' ;
   if control='CN-RH-2211' and testerid='WF-02' then testerid='W-F-02' ;
   if control='CN-RH-2404' and testerid='w-f-99' then testerid='W-F-99' ;
   if control='CN-RH-2509' and testerid='hm.sanc' then testerid='HM-SANC' ;
   if control='CN-RH-2509' and testerid='wm-lane' then testerid='WM-LANE' ;
   if control='DC-RB-0909' and testerid='450' then testerid='405' ;
   if control='DS-RB-0527' and testerid='03' then testerid='3' ;
   if control='DT-RB-0916' and testerid='212' then testerid='DET-212' ;
   if control='DT-RB-1533' and testerid='DET-201' then testerid='det-201' ;
   if control='LA-RB-0419' and testerid='mandigo' then testerid='013' ;
   if control='NO-RB-0828' and testerid='41G' then testerid='416' ;
   if control='PT-RB-1916' and testerid='31' then testerid='37' ;
   if control='CH-RH-1201' and testerid='hf02' and 
     sequence^=1 then testerid='H-F-02' ;
   if control='DN-RH-1411' and testerid='104' and
     sequence^=1 then testerid='401' ;
   if control='DS-RB-0527' and testerid='03' and 
     sequence^=1 then testerid='3' ;
   if control='DT-RB-1532' and testerid='201' then testerid='DET-201' ;

/* delete duplicate observations that were identified by UI */


   if testerid="" or substr(revid,1,1)="X"
       or substr(revid,1,1)="x" 
       or substr(revid,1,3)="pud" or
       del_rec=1 or duplicat=1 then delete ;
    else output q17 ;

proc sort ;
  by control testerid sequence ;

/* delete  additional duplicate observations by examining whether
multiple records exist for the same control number, tester id, and
unit sequence number */

proc means noprint ;
  by control testerid sequence ;
  var count ;
  output out=q17m sum=totcnt ;

data q17 dup2 dup3 ;
  merge q17 (in=q1) q17m ;
    by control testerid sequence ;
  if totcnt=2 then output dup2 ;
    else if totcnt=3 then output dup3 ;
    else output q17 ;

data dup2 ;
  set dup2 ;
  if _N_ in (1,3,5,7,9,11,13,15,17,19,21,23,25,27,29,
             31,33,35,37,39,41,43,45,47,49,51,53,55,57,59,
             61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,
             91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,
             121,123,125,127,129,131,133,135,137) then output dup2 ; 
   else delete ;

data dup3 ;
  set dup3 ;
  if _N_ in (1,4,7) then output dup3 ;
   else delete ;

/* combine final sample of unique tests */

data q17 ;
   set q17 dup2 dup3 ;

/* load sample of paired assignments */

data assign ;
  set hds2000.fassign2 ;

/* Generate average assignment information across testers.  
For lower price range, use lowest value across two testers
or the only value provided if missing for one tester.  If missing,
use zero.  For upper price range, same approach except use
highest of two values and 9999 if missing.  */

  if mpricell=. and wpricell=. then apricell=0.0 ;
    else if wpricell=. then apricell=mpricell ;
    else if mpricell=. then apricell=wpricell ;
    else if wpricell=0 then apricell=mpricell ;
    else if mpricell=0 then apricell=wpricell ;
    else if mpricell>wpricell then apricell=wpricell ;
    else apricell=mpricell ;
  
  if mpricehl=. and wpricehl=. then apricehl=9999 ;
    else if wpricehl=. then apricehl=mpricehl ;
    else if mpricehl=. then apricehl=wpricehl ;
    else if mpricehl>wpricehl then apricehl=mpricehl ;
    else apricehl=wpricehl ;

/* For minimum number of bedrooms, use lowest of two values
and set to zero if 0.5. */

  if mbedmin=. and wbedmin=. then abedmin=. ;
    else if mbedmin=. then abedmin=wbedmin ;
    else if wbedmin=. then abedmin=mbedmin ;  
    else if mbedmin<=wbedmin then abedmin=mbedmin ;
    else abedmin=mbedmin ;
  if abedmin=0.5 then abedmin=0.0 ;

/* For upper and lower range of number of bedrooms required,
use highest value provided by either tester as upper limit
and lowest value for lower limit so that upper and lower limits
will be equal if testers assigned the same value or one tester
does not report a value */


  if mbedreq=. and wbedreq=. then do ;
       abedreql=. ;
       abedrequ=. ;
       end ;
    else if mbedreq=. then do ;
       abedreql=wbedreq ;
       abedrequ=wbedreq ;
       end ;
    else if wbedreq=. then do ;
       abedreql=mbedreq ;  
       abedrequ=mbedreq ;  
       end ;
    else if mbedreq<=wbedreq then do ;
       abedreql=mbedreq ;
       abedrequ=wbedreq ;
       end ;
    else do ;
       abedreql=wbedreq ;
       abedrequ=mbedreq ;
       end ;

/*  If fractional, set lower limit to integer just above and
upper limit to integer just below. */

  if abedreql=0.5 then abedreql=0.0 ;
  if abedreql=1.5 then abedreql=1.0 ;
  if abedreql=2.5 then abedreql=2.0 ;
  if abedrequ=0.5 then abedrequ=1.0 ;
  if abedrequ=1.5 then abedrequ=2.0 ;
  if abedrequ=2.5 then abedrequ=3.0 ;
    
/* Date housing required is constructed from year, month and day 
variables.  Set these valiables to missing if entries invalid, and 
change year so that all entries are consistent. */

  if mdate_y=2001 then mdate_y=1 ;
  if mdate_y=2000 then mdate_y=0 ;
  if mdate_m in (1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12) then
       mdate_m=mdate_m ; else mdate_m=. ;
  if mdate_d in (1, 2, 3, 4, 5, 6, 7, 8, 9, 10,
                  11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 
                  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
                  31)  then
       mdate_d=mdate_d ; else mdate_d=. ;

  if wdate_y=2001 then wdate_y=1 ;
  if wdate_y=2000 then wdate_y=0 ;
  if wdate_m in (1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12) then
       wdate_m=wdate_m ; else wdate_m=. ;
  if wdate_d in (1, 2, 3, 4, 5, 6, 7, 8, 9, 10,
                  11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 
                  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
                  31)  then
       wdate_d=wdate_d ; else wdate_d=. ;

/* use latest date provided by either tester */

  if wdate_y<mdate_y then do ;
    adate_y=mdate_y ;
    adate_m=mdate_m ;
    adate_d=mdate_d ;
    end ;
  else if wdate_y>mdate_y then do ;
    adate_y=wdate_y ;
    adate_m=wdate_m ;
    adate_d=wdate_d ;
    end ;
  else if wdate_m=. and mdate_m=. then do ;
    adate_y=mdate_y ;
    adate_m=. ;
    adate_d=. ;
    end ;
  else if wdate_m=. then do ;
    adate_y=mdate_y ;
    adate_m=mdate_m ;
    adate_d=mdate_d ;
    end ;
  else if mdate_m=. then do ;
    adate_y=mdate_y ;
    adate_m=wdate_m ;
    adate_d=wdate_d ;
    end ;
  else if wdate_m>mdate_m then do ;
    adate_y=mdate_y ;
    adate_m=wdate_m ;
    adate_d=wdate_d ;
    end ;
  else if wdate_m<mdate_m then do ;
    adate_y=mdate_y ;
    adate_m=mdate_m ;
    adate_d=mdate_d ;
    end ;
  else if wdate_d=. and mdate_d=. then do ;
    adate_y=mdate_y ;
    adate_m=mdate_m ;
    adate_d=. ;
    end ;
  else if wdate_d=. then do ;
    adate_y=mdate_y ;
    adate_m=mdate_m ;
    adate_d=mdate_d ;
    end ;
  else if mdate_d=. then do ;
    adate_y=mdate_y ;
    adate_m=mdate_m ;
    adate_d=wdate_d ;
    end ;
  else if wdate_d>mdate_d then do ;
    adate_y=mdate_y ;
    adate_m=mdate_m ;
    adate_d=wdate_d ;
    end ;
  else do ;
    adate_y=mdate_y ;
    adate_m=mdate_m ;
    adate_d=mdate_d ;
    end ;

   

  if substr(control,4,1)='R' then output assign ;
    else delete ;

  keep control apricehl apricell adate_y adate_m adate_d 
    abedmin abedreql abedrequ ;

proc freq ;
  tables apricehl apricell adate_y adate_m adate_d
    abedmin abedreql abedrequ ;


proc sort ;
  by control ;

proc sort data=q17 ; by control ;

/* merge assignment information into unit data */ 

data q17 exunit exasgn ;
  merge q17 (in=q1) assign (in=q2) ;
    by control ;
  if q1=1 and q2=1 then output q17 ;
    else if q1=1 then output exunit ;
      else if substr(control,4,1)='R' then output exasgn ;
        else delete ;

/* more data cleaning */

data q17  ;
   set q17  ;

/*  Fix typo's in monthly rent fixes based on manual inspection
of data and comparison to price range and the price of other
units seen by the testers */

  if control='AT-RB-2513' and testerid='150' and
     sequence=1.0 then rurent1=1350 ;
  if control='BR-RB-1204' and testerid='07' and
     sequence=1.0 then rurent1=295 ;
  if control='CH-RB-1102' and testerid='W-F-07' and
     sequence=1.0 then rurent1=3000 ;
  if control='CH-RB-1705' and testerid='B-F-03' and
     sequence=1.0  then rurent1=1075 ;
  if control='CH-RB-1705' and testerid='W-F-04' and
     sequence=1.0 then rurent1=1175 ;
  if control='DN-RH-2022' and testerid='40' and
     sequence=1.0 then rurent1=1450 ;
  if control='PX-RN-0704' and testerid='115' and
     sequence=1.0 then rurent1=1000 ;
  if control='DN-RB-1339' and testerid='506' and
     sequence=1.0 then rurent1=1900 ;
    if control='AT-RB-1505' and sequence=2.00000 and testerid='350'  
               then    rurent1=1000.00 ;
    if control='AT-RB-1512' and sequence=2.00000 and testerid='207'  
               then    rurent1=640.0000 ;
    if control='CH-RH-1522' and sequence=3.00000 and testerid='W-F-07' 
               then    rurent1=1000.00 ;
    if control='DN-RH-2022' and sequence=2.00000 and testerid='40'  
               then    rurent1=1450.00000 ;
    if control='HO-RB-1412' and sequence=2.00000 and testerid='247' 
               then    rurent1=1000.00 ;
    if control='HO-RB-2605' and sequence=2.00000 and testerid='101' 
               then    rurent1=643.00000 ;
    if control='MA-RB-0405' and sequence=2.00000 and testerid='15'  
               then    rurent1=600.000 ;
    if control='NY-RB-0608' and sequence=2.00000 and testerid='29'  
               then    rurent1=3000.00 ;


/* The majority of security deposit information was entered as
string rather than numeric information.  The following code
generates numeric information on security deposits  */


nsecdep=. ;
isecdep=. ;

if rudepst1=1 or rudepst1=2 or rudepst1=3 then isecdep=rudepst1 ;
  else if rudepst1=6 then isecdep=0 ; 
  else isecdep=. ;

  if rudepsts='.5' then 
      isecdep=0.5  ;
  if rudepsts='.5 Months Rent' then 
      isecdep=0.5 ;
  if rudepsts='.5 rent' then 
      isecdep=0.5 ;
  if rudepsts='0 Dep.' then 
      isecdep=0 ;
  if rudepsts='0-2 months' then 
      isecdep=0 ;
  if rudepsts='1 1/2' then 
      isecdep=1.5 ;
  if rudepsts='1 1/2 mo Rent' then 
      isecdep=1.5 ;
  if rudepsts='1 1/2 mo rent w/ approval credit' then 
      isecdep=1.5 ;
  if rudepsts='1 1/2 month' then 
      isecdep=1.5 ;
  if rudepsts='1 1/2 month rent' then 
      isecdep=1.5 ;
  if rudepsts='1 1/2 months rent' then 
      isecdep=1.5 ;
  if rudepsts='1 1/2 months rent' then 
      isecdep=1.5 ;
  if rudepsts='1 1/2 mths rent' then 
      isecdep=1.5 ;
  if rudepsts='1 1/2 mths' then 
      isecdep=1.5 ;
  if rudepsts='1 mo & 1/2' then 
      isecdep=1.5 ;
  if rudepsts='1 mo plus 1 mo rent' then 
      isecdep=2.0 ;
  if rudepsts='1 mo plus same amount/rent' then 
      isecdep=2.0 ;
  if rudepsts='1 mo rent + 200.' then do ;
      isecdep=1 ;
      nsecdep=200 ;
      end ;
  if rudepsts='1 mo rent +$100' then do ;
      isecdep=1 ;
      nsecdep=100 ;
      end ;
  if rudepsts='1 mo rent+ 250' then do ;
      isecdep=1 ;
      nsecdep=250 ;
      end ;
  if rudepsts='1 mo+45 ap+250 pet dep' then 
      isecdep=1 ;
  if rudepsts='1 mo. + $100' then do ;
      isecdep=1 ;
      nsecdep=100 ;
      end ;
  if rudepsts='1 month + 50' then do ;
      isecdep=1 ;
      nsecdep= 50 ;
      end ;
  if rudepsts='1 month + 900 + 250 security fee' then do ;
      isecdep=1 ;
      nsecdep=1150 ;
      end ;
  if rudepsts='1 month +50' then do ;
      isecdep=1 ;
      nsecdep= 50 ;
      end ;
  if rudepsts='1 month deposit + 1 month security' then 
      isecdep=2  ;
  if rudepsts='1 month rent' then 
      isecdep=1   ;
  if rudepsts='1 month security + 1 month deposit' then 
      isecdep=2   ;
  if rudepsts='1 months rent + 50 for garage door opener' then do ;
      isecdep=1 ;
      nsecdep= 50 ;
      end ;
  if rudepsts='1 mth &1/2' then 
      isecdep=1.5  ;
  if rudepsts='1 mths rent + damage deposit' then 
      isecdep=1   ;
  if rudepsts='1-2 months rent' then 
      isecdep=1   ;
  if rudepsts='1-3 months depending on credit check' then 
      isecdep=1   ;
  if rudepsts='1.5' then 
      isecdep=1.5  ;
  if rudepsts='1.5 Months Rent' then 
      isecdep=1.5  ;
  if rudepsts='1.5 mnth.' then 
      isecdep=1.5  ;
  if rudepsts='1.5 mo' then 
      isecdep=1.5  ;
  if rudepsts='1.5 month' then 
      isecdep=1.5  ;
  if rudepsts='1.5 months rent' then 
      isecdep=1.5  ;
  if rudepsts='1.5 months' then 
      isecdep=1.5  ;
  if rudepsts='1.5 months rent' then 
      isecdep=1.5  ;
  if rudepsts='1.5 months rent $825' then 
      isecdep=1.5  ;
  if rudepsts='1.5 months  rent' then 
      isecdep=1.5  ;
  if rudepsts='1.5 of 1 mo. rent' then 
      isecdep=1.5  ;
  if rudepsts='1.5 times rent' then 
      isecdep=1.5  ;
  if rudepsts='1.5mths' then 
      isecdep=1.5  ;
  if rudepsts='1/2 1st mo rent' then 
      isecdep=0.5  ;
  if rudepsts='1/2 1st months rent' then 
      isecdep=0.5  ;
  if rudepsts='1/2 MTHS RENT' then 
      isecdep=0.5  ;
  if rudepsts='1/2 MTHS Rent' then 
      isecdep=0.5  ;
  if rudepsts='1/2 X rent' then 
      isecdep=0.5  ;
  if rudepsts='1/2 mo and security plus 1st and last months rent' then 
      isecdep=1.5  ;
  if rudepsts='1/2 mo rent' then 
      isecdep=0.5  ;
  if rudepsts='1/2 mo. rent' then 
      isecdep=0.5  ;
  if rudepsts='1/2 month' then 
      isecdep=0.5  ;
  if rudepsts='1/2 month rent with good credit' then 
      isecdep=0.5  ;
  if rudepsts='1/2 months rent' then 
      isecdep=0.5  ;
  if rudepsts='1/2 months rent' then 
      isecdep=0.5  ;
  if rudepsts='1/2 mths rent' then 
      isecdep=0.5  ;
  if rudepsts='1/2 of one months rent' then 
      isecdep=0.5  ;
  if rudepsts='10-12% annual rent' then 
      isecdep=1.2  ;
  if rudepsts='110% of rent' then 
      isecdep=1.1  ;
  if rudepsts='110% of tent' then 
      isecdep=1.1  ;
  if rudepsts='15% annual rent' then 
      isecdep=0.15*12  ;
  if rudepsts='1600+ one months rent' then do ;
      isecdep=1 ;
      nsecdep=1600  ;
      end ;
  if rudepsts='1mo+45 ap+ 250 pet dep' then 
      isecdep=1   ;
  if rudepsts='1st + 2 mths.' then 
      isecdep=2.0  ;
  if rudepsts='1st month rent (applied after)' then 
      isecdep=1   ;
  if rudepsts='1st, last , plus 1 month security' then 
      isecdep=2.0  ;
  if rudepsts='2 1/2 months' then 
      isecdep=2.5  ;
  if rudepsts='2 mo. min. $ 100' then 
      isecdep=2.0  ;
  if rudepsts='2 mo. rent + 1000' then do ;
      isecdep=2 ;
      nsecdep=1000  ;
      end ;
  if rudepsts='2 months minimun $ 100' then 
      isecdep=2.0  ;
  if rudepsts='2 mos rent - 1st and last' then 
      isecdep=2.0  ;
  if rudepsts='3700 & 1 months rent' then do ;
      isecdep=1 ;
      nsecdep=3700 ;
      end ;
  if rudepsts='600+ 1st & last month rent' then do ;
      isecdep=1 ;
      nsecdep=600 ;
      end ;
  if rudepsts='600+1st & last month rent' then do ;
      isecdep=1 ;
      nsecdep=600 ;
      end ;
  if rudepsts='900 + 1 months rent' then do ;
      isecdep=1 ;
      nsecdep=900 ;
      end ;
  if rudepsts='900 + 1 months rent + 250 security deposit' then do ;
      isecdep=1 ;
      nsecdep=1150;
      end ;
  if rudepsts='900 + one months rent' then do ;
      isecdep=1 ;
      nsecdep=900 ;
      end ;
  if rudepsts='If credit is good, deposit is waived' then 
      isecdep=0 ;
  if rudepsts='Depended on credit report if good, 1 month' then 
      isecdep=1 ;
  if rudepsts='Last months rent' then 
      isecdep=1 ;
  if rudepsts='No deposit since working at NCR' then 
      isecdep=0 ;
  if rudepsts='One months rent + $100 to hold apt.' then do ;
      isecdep=1 ;
      nsecdep=100 ;
      end ;
  if rudepsts='One months rent + 300' then do ;
      isecdep=1 ;
      nsecdep=300 ;
      end ;

/* should we sum these two? */

  if rudepsts='One months rent / 150.00 (tester marked both?)' then do ;
      isecdep=1 ;
      nsecdep=150  ;
      end ;

  if rudepsts='One months rent / 50 APP' then 
      isecdep=1 ;
  if rudepsts='Rent & half' then 
      isecdep=1.5;
  if rudepsts='first & last months rent' then 
      isecdep=2.0;
  if rudepsts='first months rent' then 
      isecdep=0.0 ;
  if rudepsts='half 1st month rent' then 
      isecdep=0.5;
  if rudepsts='l mo+app 45+pet dep250' then 
      isecdep=1 ;
  if rudepsts='minimum of 550' then 
      isecdep=1 ;
  if rudepsts='one Months rent less 50' then do ;
      isecdep=1 ;
      nsecdep= - 50 ;
      end ;
  if rudepsts='one and 1/2 month rent' then 
      isecdep=1.5 ;
  if rudepsts='one and a half' then 
      isecdep=1.5 ;
  if rudepsts='one and one-half mo.rent' then 
      isecdep=1.5 ;
  if rudepsts='one mo + 150 cleaning fee' then do ;
      isecdep=1 ;
      nsecdep=150  ;
      end ;
  if rudepsts='one month & $250' then do ;
      isecdep=1 ;
      nsecdep= 250 ;
      end ;
  if rudepsts='one month & $350 & $65' then do ;
      isecdep=1 ;
      nsecdep= 415 ;
      end ;
  if rudepsts='one month & 1/2' then 
      isecdep=1.5  ;
  if rudepsts='one month plus fees' then 
      isecdep=1  ;
  if rudepsts='one month rent + $300' then do ;
      isecdep=1 ;
      nsecdep= 300 ;
      end ;
  if rudepsts='one month rent + 450 for Pets' then 
      isecdep=1  ;
  if rudepsts='one month rent + half' then 
      isecdep=1.5  ;
  if rudepsts='one months + $100' then do ;
      isecdep=1 ;
      nsecdep= 100 ;
      end ;
  if rudepsts='one months and cleaning deposit' then do ;
      isecdep=1 ;
      nsecdep=150 ;
      end ;
  if rudepsts='one months plus 150 cleaning deposit' then do ;
      isecdep=1 ;
      nsecdep=150 ;
      end ;
  if rudepsts='one months rent + 50~70 (remotes&keys)' then do ;
      isecdep=1 ;
      nsecdep= 120 ;
      end ;
  if rudepsts='one months rent plus $300' then do ;
      isecdep=1 ;
      nsecdep=300 ;
      end ;
  if rudepsts='one months rent plus $300.00' then do ;
      isecdep=1 ;
      nsecdep=300 ;
      end ;
  if rudepsts='one or two mths rent.' then 
      isecdep=1  ;
  if rudepsts='two months rent +95' then do ;
      isecdep=2 ;
      nsecdep=95 ;
      end ;
  if rudepsts='waived' then 
      isecdep=0.0 ;




if rudepsts='' then do ;
    nsecdep=. ; 
    end ;
else do ;
  rudepsts=compress(rudepsts,"'") ;
  if substr(rudepsts,1,1)='$' then asecdep=
       substr(rudepsts,2,length(rudepsts)-1) ;
    else asecdep=rudepsts ;
  nsecdep=asecdep ;
  end ;

  /* generate numeric variable for security deposit comments */

  if rudepsts='$100 per good credit; $300 if credit is not good' then
      nsecdep=100 ;
  if rudepsts='$100-300' then 
      nsecdep=100 ;
  if rudepsts='$1000-1445' then 
      nsecdep=1000 ;
  if rudepsts='$150-300' then 
      nsecdep=150 ;
  if rudepsts='$199 special w/ approved credit' then 
      nsecdep=199 ;
  if rudepsts='$199-2260 depening on credit status' then 
      nsecdep=199 ;
  if rudepsts='$200-250' then 
      nsecdep=200 ;
  if rudepsts='$250 + Depending on Credit History' then 
      nsecdep=250 ;
  if rudepsts='$250 or more depending on credit history' then 
      nsecdep=250 ;
  if rudepsts='$250-400' then 
      nsecdep=250 ;
  if rudepsts='$300-$500' then 
      nsecdep=300 ;
  if rudepsts='$350 /1year lease' then 
      nsecdep=350 ;
  if rudepsts='$350 for 1 year lease' then 
      nsecdep=350 ;
  if rudepsts='$350 if 1 year lease' then 
      nsecdep=350 ;
  if rudepsts='$350/1 year lease' then 
      nsecdep=350 ;
  if rudepsts='$50 less than 1 mo rent' then 
      nsecdep=50 ;
  if rudepsts='$500 - 1 monrh depending on credit' then 
      nsecdep=500 ;
  if rudepsts='$500 up to one months rent' then 
      nsecdep=500 ;
  if rudepsts='$99 special' then 
      nsecdep=99 ;
  if rudepsts='1 mo rent-for no credit- or 250 for good credit' then 
      nsecdep=250 ;  ;
  if rudepsts='1 mo rent-no credit- or 250 for Good credit' then 
      nsecdep=250 ;
  if rudepsts='1 mo rent-w/ no credit- or 250 for good credit' then 
      nsecdep=250 ;
  if rudepsts='1 months rent , or 175' then 
      nsecdep=175 ;
  if rudepsts='100 Dep.' then 
      nsecdep=100 ;
  if rudepsts='100 if employed/ 200 if not' then 
      nsecdep=100 ;
  if rudepsts='100 to 1 month rent' then 
      nsecdep=100 ;
  if rudepsts='100 to hold apt' then 
      nsecdep=100 ;
  if rudepsts='100 up to 1 mo rent' then 
      nsecdep=100 ;
  if rudepsts='100 up to 1 month rent' then 
      nsecdep=100 ;
  if rudepsts='100 up to 1 months rent' then 
      nsecdep=100 ;
  if rudepsts='100-200' then 
      nsecdep=100 ;
  if rudepsts='100-300' then 
      nsecdep=100 ;
  if rudepsts='1000 + 100-150' then 
      nsecdep=1000 ;
  if rudepsts='10000' then 
      nsecdep=100 ;
  if rudepsts='100000' then 
      nsecdep=1000 ;
  if rudepsts='1100+35(garage opener)' then 
      nsecdep=1135 ;
  if rudepsts='1400 (2 payments)' then 
      nsecdep=1400 ;
  if rudepsts='150 (special)' then 
      nsecdep=150 ;
  if rudepsts='150 Dep.' then 
      nsecdep=150 ;
  if rudepsts='150 for Delphi Emp' then 
      nsecdep=150 ;
  if rudepsts='150 non rerundable' then 
      nsecdep=150 ;
  if rudepsts='150 paid in money order' then 
      nsecdep=150 ;
  if rudepsts='150 per adult' then 
      nsecdep=150 ;
  if rudepsts='150+30 app fee' then 
      nsecdep=150 ;
  if rudepsts='150-200' then 
      nsecdep=150 ;
  if rudepsts='150-250' then 
      nsecdep=150 ;
  if rudepsts='150-300' then 
      nsecdep=150 ;
  if rudepsts='150-350' then 
      nsecdep=150 ;
  if rudepsts='150. promo' then 
      nsecdep=150 ;
  if rudepsts='1500-1600' then 
      nsecdep=1500 ;
  if rudepsts='1500-300' then 
      nsecdep=150 ;
  if rudepsts='150to 300' then 
      nsecdep=150 ;
  if rudepsts='160 Non refundable' then 
      nsecdep=160 ;
  if rudepsts='175 or 1 months rent' then 
      nsecdep=175 ;
  if rudepsts='175-225' then 
      nsecdep=175 ;
  if rudepsts='175-275' then 
      nsecdep=175 ;
  if rudepsts='17500' then 
      nsecdep=175 ;
  if rudepsts='199 OAC' then 
      nsecdep=199 ;
  if rudepsts='199 OAC higher if not good credit' then 
      nsecdep=199 ;
  if rudepsts='199 OAL' then 
      nsecdep=199 ;
  if rudepsts='199 move in special  July rent and deposit' then 
      nsecdep=199 ;
  if rudepsts='199 move in special  july rent and deposit' then 
      nsecdep=199 ;
  if rudepsts='199(6 mo.) or 99(12 mo.)' then 
      nsecdep=99 ;
  if rudepsts='199-2200 depending on credit status' then 
      nsecdep=199 ;
  if rudepsts='199-2320 depending on credit status' then 
      nsecdep=199 ;
  if rudepsts='200 & up' then 
      nsecdep=200 ;
  if rudepsts='200 (1/2 refundable)' then 
      nsecdep=200 ;
  if rudepsts='200 before 1/1/01' then 
      nsecdep=200 ;
  if rudepsts='200 dep/125 refundable' then 
      nsecdep=200 ;
  if rudepsts='200 if sign in Dec. or 700' then 
      nsecdep=200 ;
  if rudepsts='200 more in spicial checks rent month and deposit' then 
      nsecdep=200 ;
  if rudepsts='200 or more depending upon credit' then 
      nsecdep=200 ;
  if rudepsts='200 refundable' then 
      nsecdep=200 ;
  if rudepsts='200 reg/ 50 if by 6/28/00' then 
      nsecdep=50 ;
  if rudepsts='200 reg/50 if by 6/28/00' then 
      nsecdep=50 ;
  if rudepsts='200 reg/50 move in by 6/28/00' then 
      nsecdep=50 ;
  if rudepsts='200 total move in' then 
      nsecdep=200 ;
  if rudepsts='200 up to 2 months rent' then 
      nsecdep=200 ;
  if rudepsts='200 w/125 refunded back' then 
      nsecdep=200 ;
  if rudepsts='200+up' then 
      nsecdep=200 ;
  if rudepsts='200-225' then 
      nsecdep=200 ;
  if rudepsts='200-250' then 
      nsecdep=200 ;
  if rudepsts='200-300' then 
      nsecdep=200 ;
  if rudepsts='200-350' then 
      nsecdep=200 ;
  if rudepsts='200-400' then 
      nsecdep=200 ;
  if rudepsts='200.00 + up to 1 months rent' then 
      nsecdep=200 ;
  if rudepsts='200.00 to 1 months rent' then 
      nsecdep=200 ;
  if rudepsts='2000 but no last months rent' then 
      nsecdep=2000 ;
  if rudepsts='20000' then 
      nsecdep=200 ;
  if rudepsts='225 refundable' then 
      nsecdep=225 ;
  if rudepsts='225-275' then 
      nsecdep=225 ;
  if rudepsts='25 to hold up to 150' then 
      nsecdep=25 ;
  if rudepsts='25 up to 200' then 
      nsecdep=25 ;
  if rudepsts='25-1 month' then 
      nsecdep=25 ;
  if rudepsts='25-month predictive' then 
      nsecdep=25 ;
  if rudepsts='250 + 150' then 
      nsecdep=400 ;
  if rudepsts='250 + 30' then 
      nsecdep=280 ;
  if rudepsts='250 + 50' then 
      nsecdep=300 ;
  if rudepsts='250 + 50 for husband' then 
      nsecdep=300 ;
  if rudepsts='250 + first month nonrefundable' then 
      nsecdep=250 ;
  if rudepsts='250 - 534' then 
      nsecdep=250 ;
  if rudepsts='250 - special incentive' then 
      nsecdep=250 ;
  if rudepsts='250 application fee' then 
      nsecdep=250 ;
  if rudepsts='250 or $125 if leased w/in 24 hrs.' then 
      nsecdep=125 ;
  if rudepsts='250 or 215' then 
      nsecdep=215 ;
  if rudepsts='250 to 1.5 months rent' then 
      nsecdep=250 ;
  if rudepsts='250 to 1.5 your rent' then 
      nsecdep=250 ;
  if rudepsts='250 up to 1 month rent' then 
      nsecdep=250 ;
  if rudepsts='250 up to 1 months rent' then 
      nsecdep=250 ;
  if rudepsts='250-300' then 
      nsecdep=250 ;
  if rudepsts='250-300 depending on size' then 
      nsecdep=250 ;
  if rudepsts='250-450' then 
      nsecdep=250 ;
  if rudepsts='250-500.00' then 
      nsecdep=250 ;
  if rudepsts='250-659 depend on credit check' then 
      nsecdep=250 ;
  if rudepsts='250.00 /100 nr' then 
      nsecdep=250 ;
  if rudepsts='250.00/ 100  nr' then 
      nsecdep=250 ;
  if rudepsts='25000' then 
      nsecdep=250 ;
  if rudepsts='27500' then 
      nsecdep=275 ;
  if rudepsts='280 includes 30.00 credit check + police check' then 
      nsecdep=250 ;
  if rudepsts='299 + 25 app. fee' then 
      nsecdep=299 ;
  if rudepsts='300 Non-refundable' then 
      nsecdep=300 ;
  if rudepsts='300 w/good credit' then 
      nsecdep=300 ;
  if rudepsts='300- 1 mo. rent depending on credit' then 
      nsecdep=300 ;
  if rudepsts='300-400' then 
      nsecdep=300 ;
  if rudepsts='300-450' then 
      nsecdep=300 ;
  if rudepsts='300-500' then 
      nsecdep=300 ;
  if rudepsts='300-600 Dep' then 
      nsecdep=300 ;
  if rudepsts='300.00 (non ref)' then 
      nsecdep=300 ;
  if rudepsts='300.00 based on credit' then 
      nsecdep=300 ;
  if rudepsts='300.00 min.' then 
      nsecdep=300 ;
  if rudepsts='300.00 min. dep.' then 
      nsecdep=300 ;
  if rudepsts='300.00 move in fee' then 
      nsecdep=300 ;
  if rudepsts='300/150' then 
      nsecdep=150 ;
  if rudepsts='300/450' then 
      nsecdep=450 ;
  if rudepsts='300/refundable' then 
      nsecdep=300 ;
  if rudepsts='30000' then 
      nsecdep=300 ;
  if rudepsts='31250' then 
      nsecdep=312.5 ;
  if rudepsts='350 ($200 refundable on move-out)' then 
      nsecdep=350 ;
  if rudepsts='350 to 005 depending on credit check' then 
      nsecdep=350 ;
  if rudepsts='350-1 yr lease' then 
      nsecdep=350 ;
  if rudepsts='375(include garage remote)' then 
      nsecdep=375 ;
  if rudepsts='375, special 225' then 
      nsecdep=225 ;
  if rudepsts='375/special225' then 
      nsecdep=225 ;
  if rudepsts='37500' then 
      nsecdep=375 ;
  if rudepsts='399 special' then 
      nsecdep=399 ;
  if rudepsts='400 depending on credit' then 
      nsecdep=400 ;
  if rudepsts='400 with approved credit' then 
      nsecdep=400 ;
  if rudepsts='400, (100 non-ref.)' then 
      nsecdep=400 ;
  if rudepsts='400/100 nonrefundable' then 
      nsecdep=400 ;
  if rudepsts='425,( 100 non refun.)' then 
      nsecdep=425 ;
  if rudepsts='42500' then 
      nsecdep=425 ;
  if rudepsts='475 -550' then 
      nsecdep=475 ;
  if rudepsts='5'  then 
      nsecdep=500 ;
  if rudepsts='50  non refun' then 
      nsecdep=50 ;
  if rudepsts='50 admin fee' then 
      nsecdep=50 ;
  if rudepsts='50 deposit' then 
      nsecdep=50 ;
  if rudepsts='50 non-refund' then 
      nsecdep=50 ;
  if rudepsts='50.00 more than rent' then 
      nsecdep=50 ;
  if rudepsts='500 + 75 redec. fee' then 
      nsecdep=575 ;
  if rudepsts='500 - 1 month depending on credit' then 
      nsecdep=500 ;
  if rudepsts='500 OAC' then 
      nsecdep=500 ;
  if rudepsts='500 and up' then 
      nsecdep=500 ;
  if rudepsts='500 off deposit' then 
      nsecdep=500 ;
  if rudepsts='500 or 1 mos rent depending on credit' then 
      nsecdep=500 ;
  if rudepsts='500 w/gd credit' then 
      nsecdep=500 ;
  if rudepsts='500+35 for each garage remote' then 
      nsecdep=535 ;
  if rudepsts='500+d.o.c.' then 
      nsecdep=500 ;
  if rudepsts='500-1640' then 
      nsecdep=500 ;
  if rudepsts='500-1690' then 
      nsecdep=500 ;
  if rudepsts='500-935 depending on credit check' then 
      nsecdep=500 ;
  if rudepsts='500-935 depends on credit report' then 
      nsecdep=500 ;
  if rudepsts='52500' then 
      nsecdep=525 ;
  if rudepsts='5301 dependent on credit' then 
      nsecdep=530 ;
  if rudepsts='537.51' then 
      nsecdep=537.51 ;
  if rudepsts='540-840' then 
      nsecdep=540 ;
  if rudepsts='600-700.00' then 
      nsecdep=600 ;
  if rudepsts='600.00 deposit' then 
      nsecdep=600 ;
  if rudepsts='600/300 for me' then 
      nsecdep=300 ;
  if rudepsts='625-1250' then 
      nsecdep=625 ;
  if rudepsts='710-790' then 
      nsecdep=710 ;
  if rudepsts='75 Today' then 
      nsecdep=75 ;
  if rudepsts='75-125' then 
      nsecdep=75 ;
  if rudepsts='800 maybe 1000' then 
      nsecdep=800 ;
  if rudepsts='800 to 905.' then 
      nsecdep=800 ;
  if rudepsts='800/700' then 
      nsecdep=700 ;
  if rudepsts='800/700 refundable' then 
      nsecdep=800 ;
  if rudepsts='850 if good credit' then 
      nsecdep=850 ;
  if rudepsts='885+ 50' then 
      nsecdep=935 ;
  if rudepsts='99  more-in special deposit and  1 mo rent' then 
      nsecdep=99 ;
  if rudepsts='99 plus non-refundable admin. fee 100  199' then 
      nsecdep=199 ;
  if rudepsts='99 special' then 
      nsecdep=99 ;
  if rudepsts='99-200' then 
      nsecdep=99 ;
  if rudepsts='99.00 move in' then 
      nsecdep=99 ;
  if rudepsts='Point system 25-150' then 
      nsecdep=25 ;
  if rudepsts='Point system probably 25' then 
      nsecdep=25 ;
  if rudepsts='Special for $99 until appox. Mon. 9/18' then 
      nsecdep=99 ;
  if rudepsts='from 250 depending on credit ck.' then 
      nsecdep=250 ;
  if rudepsts='move in special 35 app fee + 164 for rent' then 
      nsecdep=199 ;
  if rudepsts='move in special 99 (35 app fee + 64 rent)' then 
      nsecdep=99 ;
  if rudepsts='no deposit' then 
      nsecdep=0 ;
  if rudepsts='no deposit if credit is good' then 
      nsecdep=0 ;
  if rudepsts='no sec. deposit' then 
      nsecdep=0 ;
  if rudepsts='no security deposit but cleaning fee' then 
      nsecdep=0 ;
  if rudepsts='none' then 
      nsecdep=0 ;
  if rudepsts='none if credit is good' then 
      nsecdep=0 ;
  if rudepsts='normally 300, special 199' then 
      nsecdep=199 ;
  if rudepsts='one month to hold + $370 security' then 
      nsecdep=370 ;
  if rudepsts='one months rent plus 99 and 30 app fee' then 
      nsecdep=99 ;
  if rudepsts='special 60.90' then 
      nsecdep=60.90 ;

if nsecdep<=5 and nsecdep^=. then do ;
  isecdep=nsecdep ;
  nsecdep=. ;
  end ;


/*  Similarly, number of bedrooms is entered as a string variable
allowing a wide variety of responses.  This code generates a
numeric equivalent where one half bedroom is recorded for
studios and lofts, and an half bedroom increments are used
when the number of bedrooms is recorded with a plus or a
range */ 

if rubed1=-1 then do ;
  if rubed='loft (2 floor)' or rubed='loft: conv.2' 
        or rubed='studio/loft'  then rubed1=0 ;     
  if rubed='single/studio' or rubed='studio w/loft'    
        or rubed='0 (Single)' then rubed1=0.5 ;   
  if substr(rubed,1,1)='1' or upcase(substr(rubed,1,1))='J' then
        rubed=1.0 ;
  if substr(rubed,1,3)='1 +' or substr(rubed,1,2)='1+' or  
     substr(rubed,1,5)='1 1/2' or substr(rubed,1,6)='1 plus' or
     substr(rubed,1,3)='1-2' or substr(rubed,1,3)='1.5' or
     rubed='1w/den' then rubed1=1.5 ;
  if substr(rubed,1,1)='2' then  rubed1=2.0 ;      
  if substr(rubed,1,3)='2 +' or substr(rubed,1,2)='2+' or  
     substr(rubed,1,5)='2 1/2' or substr(rubed,1,5)='2 and' or
     substr(rubed,1,4)='2 or' or substr(rubed,1,3)='2.5' or
     rubed='2-3' or rubed='2/3' or rubed='3/2' then rubed1=2.5 ;
  if substr(rubed,1,4)='3 or' or substr(rubed,1,2)='3+' or  
     substr(rubed,1,2)='3-'  then rubed1=3.5 ;
 if rubed='4+' or rubed='4-5' or rubed='4.5' then rubed1=4.5 ;
 if rubed='5+' then rubed1=5.5 ;
 end ;
 if rubed1=-1 then rubed1=. ;

proc sort ;
  by control testerid sequence ;



proc freq ;
  tables rudepst1  isecdep nsecdep rubed1 ;


/* load census tract demographic variables */

data rdem ;
   set hds2000.runitdem ;
    aseq=trim(sequence) ; 
    stestid=trim(testerid) ;
    scontrol=trim(control) ;
    sequence=trim(sequence) ;
   keep scontrol aseq stestid mval00 pci00 pctblk pcthisp pctownoc
    povrat90 geo90 ;


/* adjust format of sequence variable for merging */

data rdem ;
  set rdem ;
  length control $32 testerid $32 ;

   control=scontrol ;
   testerid=stestid ;

   if aseq='0' then sequence=0 ;
   if aseq='1' then sequence=1 ;
   if aseq='2' then sequence=2 ;
   if aseq='3' then sequence=3 ;
   if aseq='4' then sequence=4 ;
   if aseq='5' then sequence=5 ;
   if aseq='6' then sequence=6 ;
   if aseq='7' then sequence=7 ;
   if aseq='8' then sequence=8 ;
   if aseq='9' then sequence=9 ;
   if aseq='10' then sequence=10 ;

proc sort ;
  by control testerid sequence ;


/* merge in demographic informations */


data q17 ;
  merge  q17 (in=q1) rdem (in=q2) ;
     by control testerid sequence ;
     if q1 ;     

    match=q2 ;

proc means ;
  var mval00 pci00 pctblk pcthisp pctownoc povrat90 ;



/* save the final sample of rental units */

data hds2000.q17nodup ;
  set q17 ;
  if mval00=0 then do ;
    mval00=. ; pci00=. ; pctblk=. ; pcthisp=. ;
    pctownoc=. ; povrat90=. ;
    end ;


proc means ;
  var mval00 pci00 pctblk pcthisp pctownoc povrat90 ;




run ;

