****************************************************************
* Program name:  sales_metro.sas
* Project:       Housing Discrimination Study Phase I
*
*  Final version: March 15, 2002 by Steve Ross
*
*  This program uses data from the 2000 sales housing discrimination 
*  studies in order to generate metro level estimates of adverse 
*  treatment The results are found in table format in the sas list 
*  file, sales_metro.lst.
*  
* Input Files:   fnslsmrg.ssd01, isteer00.ssd01, rsteer00.ssd01
*
* Output Files:  none
*                                            
****************************************************************;

options nocenter ;

libname hds '/mnt/jayhawk/jayproj/hds2000' ;

filename fnslsmrg '/mnt/jayhawk/jayproj/hds2000/fnslsmrg.ssd01' ;
filename isteer00 '/mnt/jayhawk/jayproj/hds2000/isteer00.ssd01' ;
filename rsteer00 '/mnt/jayhawk/jayproj/hds2000/rsteer00.ssd01' ;

data hds2000 ;
  set hds.fnslsmrg ;

  year='2000' ;
  type=substr(control,5,1) ;


/* delete observations that are not core */

  if site='AZ' then site='TC' ;
  if site='AN' or site='CN' or
   site='LN' or site='NN' or site='SN' or 
   site='AX' or site='CX' or site='LX' or
   site='NX' or site='SX' then delete ;
     else output hds2000 ; 

proc sort ;
  by control ;

/* bring in steering information */

data st2000i ;
  set hds.isteer00 ;
  whtnspct=wttrinc ;
  ownnspct=ootrinc ;
  povnspct=pvtrinc ;
  keep control whtnspct ownnspct povnspct ;

proc sort ;
  by control ;


data st2000r ;
  set hds.rsteer00 ;
  whtrec=wttrinc ;
  ownrec=ootrinc ;
  povrec=pvtrinc ;
  keep control whtrec ownrec povrec ;

proc sort ;
  by control ;



data hds2000 ;
  merge hds2000 (in=q1) st2000i (in=q2) st2000r (in=q3) ;
  by control ; if q1 ;

proc sort ; by type site ;

data bwtests ;
  set hds2000 ;


/* create treatement variables */


rsteer11=0 ; rsteer10=0 ; rsteer01=0 ; rsteerc=1 ;
if whtrec=0 then rsteer11=1 ;
  else if whtrec=1 then rsteer10=1 ;
  else if whtrec=-1 then rsteer01=1 ;

isteer11=0 ; isteer10=0 ; isteer01=0 ; isteerc=1 ;
if whtnspct=0 then isteer11=1 ;
  else if whtnspct=1 then isteer10=1 ;
  else if whtnspct=-1 then isteer01=1 ;

avail11=0 ; avail10=0 ; avail01=0 ; availc=1 ;
if wavailad=1 and mavailad=1 then avail11=1 ;
  else if wavailad=1 and mavailad=0 then avail10=1 ;
  else if wavailad=0 and mavailad=1 then avail01=1 ;

avlsm11=0 ; avlsm10=0 ; avlsm01=0 ; avlsmc=1 ;
if wavailsm=1 and mavailsm=1 then avlsm11=1 ;
  else if wavailsm=1 and mavailsm=0 then avlsm10=1 ;
  else if wavailsm=0 and mavailsm=1 then avlsm01=1 ;

recom11=0 ; recom10=0 ; recom01=0 ; recomc=1 ;
if wrecomi=1 and mrecomi=1 then recom11=1 ;
  else if wrecomi=1 and mrecomi=0 then recom10=1 ;
  else if wrecomi=0 and mrecomi=1 then recom01=1 ;


waccess=0 ; maccess=0 ; 
if avail10=1 then waccess=1 ;
  else if avail01=1 then maccess=1 ;
  else if avlsm10=1 then waccess=1 ;
  else if avlsm01=1 then maccess=1 ;
  else if recom10=1 then waccess=1 ;
  else if recom01=1 then maccess=1 ;


wacccns=0 ; macccns=0 ; 
if (avail10=1 or avlsm10=1 or recom10=1) then wacccns=1 ;
if (avail01=1 or avlsm01=1 or recom01=1) then macccns=1 ;


  
inspad11=0 ; inspad10=0 ; inspad01=0 ; inspadc=1 ;
if winspadv=1 and minspadv=1 then inspad11=1 ;
  else if winspadv=1 and minspadv=0 then inspad10=1 ;
  else if winspadv=0 and minspadv=1 then inspad01=1 ;

inspsm11=0 ; inspsm10=0 ; inspsm01=0 ; inspsmc=1 ;
if winspsim=1 and minspsim=1 then inspsm11=1 ;
  else if winspsim=1 and minspsim=0 then inspsm10=1 ;
  else if winspsim=0 and minspsim=1 then inspsm01=1 ;

inspct11=0 ; inspct10=0 ; inspct01=0 ; inspctc=1 ;
if winspcti=1 and minspcti=1 then inspct11=1 ;
  else if winspcti=1 and minspcti=0 then inspct10=1 ;
  else if winspcti=0 and minspcti=1 then inspct01=1 ;

waccss2=0 ; maccss2=0 ;
if inspad10=1 then waccss2=1 ;
else if inspad01=1 then maccss2=1 ;
else if inspsm10=1 then waccss2=1 ;
else if inspsm01=1 then maccss2=1 ;
else if inspct10=1 then waccss2=1 ;
else if inspct01=1 then maccss2=1 ;

wacc2cns=0 ; macc2cns=0 ;
if (inspad10=1 or inspsm10=1 or inspct10=1) then wacc2cns=1 ;
if (inspad01=1 or inspsm01=1 or inspct01=1) then macc2cns=1 ;


nofutc11=0 ; nofutc10=0 ; nofutc01=0 ; nofutcc=1 ;
if wnofutcn=1 and mnofutcn=1 then nofutc11=1 ;
  else if wnofutcn=1 and mnofutcn=0 then nofutc01=1 ;
  else if wnofutcn=0 and mnofutcn=1 then nofutc10=1 ;

follow11=0 ; follow10=0 ; follow01=0 ; followc=1 ;
if wfollow=1 and mfollow=1 then follow11=1 ;
  else if wfollow=1 and mfollow=0 then follow10=1 ;
  else if wfollow=0 and mfollow=1 then follow01=1 ;

qual11=0 ; qual10=0 ; qual01=0 ; qualc=1 ;
if wqual=1 and mqual=1 then qual11=1 ;
  else if wqual=1 and mqual=0 then qual10=1 ;
  else if wqual=0 and mqual=1 then qual01=1 ;

mservice=0 ; wservice=0 ;
if follow10=1 then wservice=1 ;
  else if follow01=1 then mservice=1 ;
  else if qual10=1 then wservice=1 ;
  else if qual01=1 then mservice=1 ;
  else if nofutc10=1 then wservice=1 ;
  else if nofutc01=1 then mservice=1 ;



mservcns=0 ; wservcns=0 ;
if (follow10=1 or nofutc10=1 or qual10=1)
   then wservcns=1 ;
if (follow01=1 or nofutc01=1 or qual01=1)
   then mservcns=1 ;



finhlp11=0 ; finhlp10=0 ; finhlp01=0 ; finhlpc=1 ;
if wfinhelp=1 and mfinhelp=1 then finhlp11=1 ;
if wfinhelp=1 and mfinhelp=0 then finhlp10=1 ;
if wfinhelp=0 and mfinhelp=1 then finhlp01=1 ;

lndr11=0 ; lndr10=0 ; lndr01=0 ; lndrc=1 ;
if wlenders=1 and mlenders=1 then lndr11=1 ;
if wlenders=1 and mlenders=0 then lndr10=1 ;
if wlenders=0 and mlenders=1 then lndr01=1 ;

dwnpay11=0 ; dwnpay10=0 ; dwnpay01=0 ; dwnpayc=1 ;
if wdownpay=1 and mdownpay=1 then dwnpay11=1 ;
if wdownpay=1 and mdownpay=0 then dwnpay10=1 ;
if wdownpay=0 and mdownpay=1 then dwnpay01=1 ;

wfnce=0 ; mfnce=0 ;
if finhlp10=1 then wfnce=1 ;
else if finhlp01=1 then mfnce=1 ;
else if lndr10=1 then wfnce=1 ;
else if lndr01=1 then mfnce=1 ;
else if dwnpay10=1 then wfnce=1 ;
else if dwnpay01=1 then mfnce=1 ;

wfincns=0 ; mfincns=0 ;
if (finhlp10=1 or lndr10=1 or dwnpay10=1) then wfincns=1 ; 
if (finhlp01=1 or lndr01=1 or dwnpay01=1) then mfincns=1 ; 

access11=0 ; access10=0 ; access01=0 ; accessc=1 ;
if waccess=1 and maccess=1 then access11=1 ;
if waccess=1 and maccess=0 then access10=1 ;
if waccess=0 and maccess=1 then access01=1 ;

accss211=0 ; accss210=0 ; accss201=0 ; accss2c=1 ;
if waccss2=1 and maccss2=1 then accss211=1 ;
if waccss2=1 and maccss2=0 then accss210=1 ;
if waccss2=0 and maccss2=1 then accss201=1 ;

servic11=0 ; servic10=0 ; servic01=0 ; servicc=1 ;
if wservice=1 and mservice=1 then servic11=1 ;
if wservice=1 and mservice=0 then servic10=1 ;
if wservice=0 and mservice=1 then servic01=1 ;

fnce11=0 ; fnce10=0 ; fnce01=0 ; fncec=1 ;
if wfnce=1 and mfnce=1 then fnce11=1 ;
if wfnce=1 and mfnce=0 then fnce10=1 ;
if wfnce=0 and mfnce=1 then fnce01=1 ;

acccns11=0 ; acccns10=0 ; acccns01=0 ; acccnsc=1 ;
if wacccns=1 and macccns=1 then acccns11=1 ;
if wacccns=1 and macccns=0 then acccns10=1 ;
if wacccns=0 and macccns=1 then acccns01=1 ;

ac2cns11=0 ; ac2cns10=0 ; ac2cns01=0 ; ac2cnsc=1 ;
if wacc2cns=1 and macc2cns=1 then ac2cns11=1 ;
if wacc2cns=1 and macc2cns=0 then ac2cns10=1 ;
if wacc2cns=0 and macc2cns=1 then ac2cns01=1 ;

srvcns11=0 ; srvcns10=0 ; srvcns01=0 ; srvcnsc=1 ;
if wservcns=1 and mservcns=1 then srvcns11=1 ;
if wservcns=1 and mservcns=0 then srvcns10=1 ;
if wservcns=0 and mservcns=1 then srvcns01=1 ;

fincns11=0 ; fincns10=0 ; fincns01=0 ; fincnsc=1 ;
if wfincns=1 and mfincns=1 then fincns11=1 ; 
if wfincns=1 and mfincns=0 then fincns10=1 ; 
if wfincns=0 and mfincns=1 then fincns01=1 ; 

cnsty11=0 ; cnsty10=0 ; cnsty01=0 ; cnstyc=1 ;
if (wfincns=1 or wservcns=1 or wacccns=1 or wacc2cns=1) and
   (mfincns=1 or mservcns=1 or macccns=1 or macc2cns=1) 
   then cnsty11=1 ;
else if (wfincns=1 or wservcns=1 or wacccns=1 or wacc2cns=1
     or rsteer10=1 or isteer10=1) and mfincns=0 and
     mservcns=0 and macccns=0 and macc2cns=0 and
     rsteer01=0 and isteer01=0 then cnsty10=1 ;
else if (mfincns=1 or mservcns=1 or macccns=1 or macc2cns=1
     or rsteer01=1 or isteer01=1)  and wfincns=0 and
     wservcns=0 and wacccns=0 and wacc2cns=0 and
     rsteer10=0 and isteer10=0 then cnsty01=1 ;

/* create heirarchy composite variables */


wheir1=0 ;
wheir2=0 ;
wheir3=0 ;
wheir4=0 ;
wheir5=0 ;
wheir6=0 ;
wheir7=0 ;
wheir8=0 ;
wheir9=0 ;
wheir10=0 ;
wheir11=0 ;
wheir12=0 ;
wheir13=0 ;
wheir14=0 ;
mheir1=0 ;
mheir2=0 ;
mheir3=0 ;
mheir4=0 ;
mheir5=0 ;
mheir6=0 ;
mheir7=0 ;
mheir8=0 ;
mheir9=0 ;
mheir10=0 ;
mheir11=0 ;
mheir12=0 ;
mheir13=0 ;
mheir14=0 ;
if avail10=1 then do ; 
  wheir1=1 ;
  wheir2=1 ;
  wheir3=1 ;
  wheir4=1 ;
  wheir5=1 ;
  wheir6=1 ;
  wheir7=1 ;
  wheir8=1 ;
  wheir9=1 ;
  wheir10=1 ;
  wheir11=1 ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if avail01=1 then do ;
  mheir1=1 ;
  mheir2=1 ;
  mheir3=1 ;
  mheir4=1 ;
  mheir5=1 ;
  mheir6=1 ;
  mheir7=1 ;
  mheir8=1 ;
  mheir9=1 ;
  mheir10=1 ;
  mheir11=1 ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if inspad10=1 then do ;
  wheir2=1 ;
  wheir3=1 ;
  wheir4=1 ;
  wheir5=1 ;
  wheir6=1 ;
  wheir7=1 ;
  wheir8=1 ;
  wheir9=1 ;
  wheir10=1 ;
  wheir11=1 ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if inspad01=1 then do ;
  mheir2=1 ;
  mheir3=1 ;
  mheir4=1 ;
  mheir5=1 ;
  mheir6=1 ;
  mheir7=1 ;
  mheir8=1 ;
  mheir9=1 ;
  mheir10=1 ;
  mheir11=1 ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if avlsm10=1 then  do ;
  wheir3=1 ;
  wheir4=1 ;
  wheir5=1 ;
  wheir6=1 ;
  wheir7=1 ;
  wheir8=1 ;
  wheir9=1 ;
  wheir10=1 ;
  wheir11=1 ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if avlsm01=1 then  do ;
  mheir3=1 ;
  mheir4=1 ;
  mheir5=1 ;
  mheir6=1 ;
  mheir7=1 ;
  mheir8=1 ;
  mheir9=1 ;
  mheir10=1 ;
  mheir11=1 ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if inspsm10=1 then do ;
  wheir4=1 ;
  wheir5=1 ;
  wheir6=1 ;
  wheir7=1 ;
  wheir8=1 ;
  wheir9=1 ;
  wheir10=1 ;
  wheir11=1 ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if inspsm01=1 then do ;
  mheir4=1 ;
  mheir5=1 ;
  mheir6=1 ;
  mheir7=1 ;
  mheir8=1 ;
  mheir9=1 ;
  mheir10=1 ;
  mheir11=1 ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if rsteer10=1 then do ;
  wheir5=1 ;
  wheir6=1 ;
  wheir7=1 ;
  wheir8=1 ;
  wheir9=1 ;
  wheir10=1 ;
  wheir11=1 ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if rsteer01=1 then do ;
  mheir5=1 ;
  mheir6=1 ;
  mheir7=1 ;
  mheir8=1 ;
  mheir9=1 ;
  mheir10=1 ;
  mheir11=1 ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if recom10=1 then  do ;
  wheir6=1 ;
  wheir7=1 ;
  wheir8=1 ;
  wheir9=1 ;
  wheir10=1 ;
  wheir11=1 ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if recom01=1 then  do ;
  mheir6=1 ;
  mheir7=1 ;
  mheir8=1 ;
  mheir9=1 ;
  mheir10=1 ;
  mheir11=1 ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if isteer10=1 then do ;
  wheir7=1 ;
  wheir8=1 ;
  wheir9=1 ;
  wheir10=1 ;
  wheir11=1 ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if isteer01=1 then do ;
  mheir7=1 ;
  mheir8=1 ;
  mheir9=1 ;
  mheir10=1 ;
  mheir11=1 ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if inspct10=1 then do ;
  wheir8=1 ;
  wheir9=1 ;
  wheir10=1 ;
  wheir11=1 ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if inspct01=1 then do ;
  mheir8=1 ;
  mheir9=1 ;
  mheir10=1 ;
  mheir11=1 ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if finhlp10=1 then do ;
  wheir9=1 ;
  wheir10=1 ;
  wheir11=1 ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if finhlp01=1 then do ;
  mheir9=1 ;
  mheir10=1 ;
  mheir11=1 ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if lndr10=1 then do ;
  wheir10=1 ;
  wheir11=1 ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if lndr01=1 then do ;
  mheir10=1 ;
  mheir11=1 ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if dwnpay10=1 then do ;
  wheir11=1 ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if dwnpay01=1 then do ;
  mheir11=1 ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if follow10=1 then do ;
  wheir12=1 ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if follow01=1 then do ;
  mheir12=1 ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if qual10=1 then do ;
  wheir13=1 ;
  wheir14=1 ;
  end ;
  else if qual01=1 then do ;
  mheir13=1 ;
  mheir14=1 ;
  end ;
  else if nofutc10=1 then  do ;
  wheir14=1 ;
  end ;
  else if nofutc01=1 then  do ;
  mheir14=1 ;
  end ;



hr1q11=0 ; hr1q10=0 ; hr1q01=0 ; hr1qc=1 ;
if wheir1=1 and mheir1=1 then hr1q11=1 ; 
if wheir1=1 and mheir1=0 then hr1q10=1 ; 
if wheir1=0 and mheir1=1 then hr1q01=1 ; 


hr2q11=0 ; hr2q10=0 ; hr2q01=0 ; hr2qc=1 ;
if wheir2=1 and mheir2=1 then hr2q11=1 ; 
if wheir2=1 and mheir2=0 then hr2q10=1 ; 
if wheir2=0 and mheir2=1 then hr2q01=1 ; 


hr3q11=0 ; hr3q10=0 ; hr3q01=0 ; hr3qc=1 ;
if wheir3=1 and mheir3=1 then hr3q11=1 ; 
if wheir3=1 and mheir3=0 then hr3q10=1 ; 
if wheir3=0 and mheir3=1 then hr3q01=1 ; 


hr4q11=0 ; hr4q10=0 ; hr4q01=0 ; hr4qc=1 ;
if wheir4=1 and mheir4=1 then hr4q11=1 ; 
if wheir4=1 and mheir4=0 then hr4q10=1 ; 
if wheir4=0 and mheir4=1 then hr4q01=1 ; 


hr5q11=0 ; hr5q10=0 ; hr5q01=0 ; hr5qc=1 ;
if wheir5=1 and mheir5=1 then hr5q11=1 ; 
if wheir5=1 and mheir5=0 then hr5q10=1 ; 
if wheir5=0 and mheir5=1 then hr5q01=1 ; 


hr6q11=0 ; hr6q10=0 ; hr6q01=0 ; hr6qc=1 ;
if wheir6=1 and mheir6=1 then hr6q11=1 ; 
if wheir6=1 and mheir6=0 then hr6q10=1 ; 
if wheir6=0 and mheir6=1 then hr6q01=1 ; 


hr7q11=0 ; hr7q10=0 ; hr7q01=0 ; hr7qc=1 ;
if wheir7=1 and mheir7=1 then hr7q11=1 ; 
if wheir7=1 and mheir7=0 then hr7q10=1 ; 
if wheir7=0 and mheir7=1 then hr7q01=1 ; 


hr8q11=0 ; hr8q10=0 ; hr8q01=0 ; hr8qc=1 ;
if wheir8=1 and mheir8=1 then hr8q11=1 ; 
if wheir8=1 and mheir8=0 then hr8q10=1 ; 
if wheir8=0 and mheir8=1 then hr8q01=1 ; 


hr9q11=0 ; hr9q10=0 ; hr9q01=0 ; hr9qc=1 ;
if wheir9=1 and mheir9=1 then hr9q11=1 ; 
if wheir9=1 and mheir9=0 then hr9q10=1 ; 
if wheir9=0 and mheir9=1 then hr9q01=1 ; 


hr10q11=0 ; hr10q10=0 ; hr10q01=0 ; hr10qc=1 ;
if wheir10=1 and mheir10=1 then hr10q11=1 ; 
if wheir10=1 and mheir10=0 then hr10q10=1 ; 
if wheir10=0 and mheir10=1 then hr10q01=1 ; 


hr11q11=0 ; hr11q10=0 ; hr11q01=0 ; hr11qc=1 ;
if wheir11=1 and mheir11=1 then hr11q11=1 ; 
if wheir11=1 and mheir11=0 then hr11q10=1 ; 
if wheir11=0 and mheir11=1 then hr11q01=1 ; 


hr12q11=0 ; hr12q10=0 ; hr12q01=0 ; hr12qc=1 ;
if wheir12=1 and mheir12=1 then hr12q11=1 ; 
if wheir12=1 and mheir12=0 then hr12q10=1 ; 
if wheir12=0 and mheir12=1 then hr12q01=1 ; 

hr13q11=0 ; hr13q10=0 ; hr13q01=0 ; hr13qc=1 ;
if wheir13=1 and mheir13=1 then hr13q11=1 ; 
if wheir13=1 and mheir13=0 then hr13q10=1 ; 
if wheir13=0 and mheir13=1 then hr13q01=1 ; 

hr14q11=0 ; hr14q10=0 ; hr14q01=0 ; hr14qc=1 ;
if wheir14=1 and mheir14=1 then hr14q11=1 ; 
if wheir14=1 and mheir14=0 then hr14q10=1 ; 
if wheir14=0 and mheir14=1 then hr14q01=1 ; 

/* create sample of outcomes for each treatment variable where
the sample covers all sites and types of tests. */


proc means noprint data=bwtests ; 
   var avail11 avail10 avail01 availc ;
   output out=avail mean=equal white black sum=c11 c10 c01 valid ;
     by type site ;

data avail ;
  set avail ;
  variable='availadv' ;
  count=1 ;

proc means noprint  data=bwtests ; 
   var avlsm11 avlsm10 avlsm01  avlsmc ;
   output out=avlsm mean=equal white black sum=c11 c10 c01 valid ;
     by type site ;


data avlsm ;
  set avlsm ;
  variable='availsim' ;
  count=2 ;

proc means noprint  data=bwtests ; 
   var recom11 recom10 recom01 recomc ;
   output out=recom mean=equal white black  sum=c11 c10 c01 valid ;
     by type site ;

data recom ;
  set recom ;
  variable='recom' ;
  count=3 ;

proc means noprint  data=bwtests ; 
   var access11 access10 access01 accessc ;
   output out=access mean=equal white black  sum=c11 c10 c01 valid ;
     by type site ;

data access ;
  set access ;
  variable='access' ;
  count=4 ;

proc means noprint  data=bwtests ; 
   var acccns11 acccns10 acccns01 acccnsc ;
   output out=acccns mean=equal white black  sum=c11 c10 c01 valid ;
     by type site ;

data acccns ;
  set acccns ;
  variable='acccns' ;
  count=5 ;



proc means noprint  data=bwtests ; 
   var inspad11 inspad10 inspad01 inspadc ;
   output out=inspad mean=equal white black sum=c11 c10 c01 valid ;
     by type site ;


data inspad ;
  set inspad ;
  variable='inspad' ;
  count=6 ;

proc means noprint  data=bwtests ; 
   var inspsm11 inspsm10 inspsm01 inspsmc ;
   output out=inspsm mean=equal white black  sum=c11 c10 c01 valid ;
     by type site ;

data inspsm ;
  set inspsm ;
  variable='inspsm' ;
  count=7 ;

proc means noprint  data=bwtests ; 
   var inspct11 inspct10 inspct01 inspctc ;
   output out=inspct mean=equal white black  sum=c11 c10 c01 valid ;
     by type site ;

data inspct ;
  set inspct ;
  variable='inspect' ;
  count=8 ;

proc means noprint  data=bwtests ; 
   var accss211 accss210 accss201 accss2c ;
   output out=access2 mean=equal white black  sum=c11 c10 c01 valid ;
     by type site ;

data access2 ;
  set access2 ;
  variable='access2' ;
  count=9 ;


proc means noprint  data=bwtests ; 
   var ac2cns11 ac2cns10 ac2cns01 ac2cnsc ;
   output out=acc2cns mean=equal white black  sum=c11 c10 c01 valid ;
     by type site ;

data acc2cns ;
  set acc2cns ;
  variable='acc2cns' ;
  count=10 ;

proc means noprint  data=bwtests ; 
   var finhlp11 finhlp10 finhlp01 finhlpc ;
   output out=finhlp mean=equal white black sum=c11 c10 c01 valid ;
     by type site ;

data finhlp ;
  set finhlp ;
  variable='finhlp' ;
  count=11 ;


proc means noprint  data=bwtests ; 
   var lndr11 lndr10 lndr01 lndrc ;
   output out=lndr mean=equal white black sum=c11 c10 c01 valid ;
     by type site ;


data lndr ;
  set lndr ;
  variable='lndr' ;
  count=12 ;



proc means noprint  data=bwtests ; 
   var dwnpay11 dwnpay10 dwnpay01 dwnpayc ;
   output out=dwnpay mean=equal white black sum=c11 c10 c01 valid ;
     by type site ;


data dwnpay ;
  set dwnpay ;
  variable='dwnpay' ;
  count=13 ;

proc means noprint  data=bwtests ; 
   var fnce11 fnce10 fnce01 fncec ;
   output out=fnce mean=equal white black sum=c11 c10 c01 valid ;
     by type site ;


data fnce ;
  set fnce ;
  variable='fnce' ;
  count=15 ;


proc means noprint  data=bwtests ; 
   var fincns11 fincns10 fincns01 fincnsc ;
   output out=fincns mean=equal white black sum=c11 c10 c01 valid ;
     by type site ;


data fincns ;
  set fincns ;
  variable='fincns' ;
  count=16 ;



proc means noprint  data=bwtests ; 
   var follow11 follow10 follow01 followc ;
   output out=follow mean=equal white black sum=c11 c10 c01 valid  ;
     by type site ;


data follow ;
  set follow ;
  variable='follow' ;
  count=17 ;



proc means noprint  data=bwtests ; 
   var qual11 qual10 qual01 qualc ;
   output out=qual mean=equal white black sum=c11 c10 c01 valid  ;
     by type site ;


data qual ;
  set qual ;
  variable='qual' ;
  count=18 ;



proc means noprint  data=bwtests ; 
   var nofutc11 nofutc10 nofutc01 nofutcc;
   output out=nofutcon mean=equal white black  sum=c11 c10 c01 valid ;
     by type site ;


data nofutcon ;
  set nofutcon ;
  variable='nofutcon' ;
  count=19 ;



proc means noprint  data=bwtests ; 
   var servic11 servic10 servic01 servicc ;
   output out=servic mean=equal white black sum=c11 c10 c01 valid  ;
     by type site ;


data servic ;
  set servic ;
  variable='service' ;
  count=21 ;



proc means noprint  data=bwtests ; 
   var srvcns11 srvcns10 srvcns01 srvcnsc ;
   output out=servcns mean=equal white black sum=c11 c10 c01 valid  ;
     by type site ;

data servcns ;
  set servcns ;
  variable='servcns' ;
  count=22 ;

data avail2 ;
  set avail ;
  variable='availadv' ;
  count=23 ;

data inspad2 ;
  set inspad ;
  variable='inspad' ;
  count=24 ;

data avlsm2 ;
  set avlsm ;
  variable='availsim' ;
  count=25 ;

data inspsm2 ;
  set inspsm ;
  variable='inspsm' ;
  count=26 ;

proc means noprint data=bwtests ; 
   var rsteer11 rsteer10 rsteer01 rsteerc ;
   output out=rsteer mean=equal white black sum=c11 c10 c01 valid  ;
     by type site ;

data rsteer2 ;
  set rsteer ;
  variable='rsteer' ;
  count=27 ;

data recom2 ;
  set recom ;
  variable='recom' ;
  count=28 ;

proc means noprint data=bwtests ; 
   var isteer11 isteer10 isteer01 isteerc ;
   output out=isteer mean=equal white black sum=c11 c10 c01 valid  ;
     by type site ;

data isteer2 ;
  set isteer ;
  variable='isteer' ;
  count=29 ;


data inspct2 ;
  set inspct ;
  variable='inspect' ;
  count=30 ;

data finhlp2 ;
  set finhlp ;
  variable='finhlp' ;
  count=31 ;

data lndr2 ;
  set lndr ;
  variable='lndr' ;
  count=32 ;

data dwnpay2 ;
  set dwnpay ;
  variable='dwnpay' ;
  count=33 ;


data follow2 ;
  set follow ;
  variable='follow' ;
  count=34 ;


data qual2 ;
  set qual ;
  variable='qual' ;
  count=35 ;


data nofutco2 ;
  set nofutcon ;
  variable='nofutcon' ;
  count=36 ;


proc means noprint  data=bwtests ; 
   var hr1q11 hr1q10 hr1q01 hr1qc ;
   output out=heir1 mean=equal white black sum=c11 c10 c01 valid  ;
     by type site ;


data heir1 ;
  set heir1 ;
  variable='heir1' ;
  count=37 ;


proc means noprint  data=bwtests ; 
   var hr2q11 hr2q10 hr2q01 hr2qc ;
   output out=heir2 mean=equal white black sum=c11 c10 c01 valid  ;
     by type site ;


data heir2 ;
  set heir2 ;
  variable='heir2' ;
  count=38 ;


proc means noprint  data=bwtests ; 
   var hr3q11 hr3q10 hr3q01 hr3qc ;
   output out=heir3 mean=equal white black sum=c11 c10 c01 valid  ;
     by type site ;


data heir3 ;
  set heir3 ;
  variable='heir3' ;
  count=39 ;


proc means noprint  data=bwtests ; 
   var hr4q11 hr4q10 hr4q01 hr4qc ;
   output out=heir4 mean=equal white black sum=c11 c10 c01 valid  ;
     by type site ;


data heir4 ;
  set heir4 ;
  variable='heir4' ;
  count=40 ;


proc means noprint  data=bwtests ; 
   var hr5q11 hr5q10 hr5q01 hr5qc ;
   output out=heir5 mean=equal white black sum=c11 c10 c01 valid  ;
     by type site ;


data heir5 ;
  set heir5 ;
  variable='heir5' ;
  count=41 ;


proc means noprint  data=bwtests ; 
   var hr6q11 hr6q10 hr6q01 hr6qc ;
   output out=heir6 mean=equal white black sum=c11 c10 c01 valid  ;
     by type site ;


data heir6 ;
  set heir6 ;
  variable='heir6' ;
  count=42 ;


proc means noprint  data=bwtests ; 
   var hr7q11 hr7q10 hr7q01 hr7qc ;
   output out=heir7 mean=equal white black sum=c11 c10 c01 valid  ;
     by type site ;


data heir7 ;
  set heir7 ;
  variable='heir7' ;
  count=43 ;


proc means noprint  data=bwtests ; 
   var hr8q11 hr8q10 hr8q01 hr8qc ;
   output out=heir8 mean=equal white black sum=c11 c10 c01 valid  ;
     by type site ;


data heir8 ;
  set heir8 ;
  variable='heir8' ;
  count=44 ;


proc means noprint  data=bwtests ; 
   var hr9q11 hr9q10 hr9q01 hr9qc ;
   output out=heir9 mean=equal white black sum=c11 c10 c01 valid  ;
     by type site ;


data heir9 ;
  set heir9 ;
  variable='heir9' ;
  count=45 ;


proc means noprint  data=bwtests ; 
   var hr10q11 hr10q10 hr10q01 hr10qc ;
   output out=heir10 mean=equal white black sum=c11 c10 c01 valid  ;
     by type site ;


data heir10 ;
  set heir10 ;
  variable='heir10' ;
  count=46 ;


proc means noprint  data=bwtests ; 
   var hr11q11 hr11q10 hr11q01 hr11qc ;
   output out=heir11 mean=equal white black sum=c11 c10 c01 valid  ;
     by type site ;


data heir11 ;
  set heir11 ;
  variable='heir11' ;
  count=47 ;


proc means noprint  data=bwtests ; 
   var hr12q11 hr12q10 hr12q01 hr12qc ;
   output out=heir12 mean=equal white black sum=c11 c10 c01 valid  ;
     by type site ;


data heir12 ;
  set heir12 ;
  variable='heir12' ;
  count=48 ;


proc means noprint  data=bwtests ; 
   var hr13q11 hr13q10 hr13q01 hr13qc ;
   output out=heir13 mean=equal white black sum=c11 c10 c01 valid  ;
     by type site ;


data heir13 ;
  set heir13 ;
  variable='heir13' ;
  count=49 ;


proc means noprint  data=bwtests ; 
   var hr14q11 hr14q10 hr14q01 hr14qc ;
   output out=heir14 mean=equal white black sum=c11 c10 c01 valid  ;
     by type site ;


data heir14 ;
  set heir14 ;
  variable='heir14' ;
  count=50 ;

data heirfin ;
  set heir14 ;
  variable='heirfin' ;
  count=51 ;



proc means noprint  data=bwtests ; 
   var cnsty11 cnsty10 cnsty01 cnstyc ;
   output out=cnsty mean=equal white black sum=c11 c10 c01 valid  ;
     by type site ;


data cnsty ;
  set cnsty ;
  variable='cnsty' ;
  count=52 ;

/* create gross and net measures along with standard errors */

data bwstat ;
  set avail avlsm recom access acccns
      inspad inspsm inspct access2 acc2cns
      finhlp lndr dwnpay fnce fincns
      follow qual nofutcon servic servcns 
      cnsty heirfin ;

  net=white-black ;
  probw=equal+white ;
  probb=equal+black ;
  var=(probw*(1-probw) + probb*(1-probb) - 2 * (equal * ( 1 -
   equal - white - black) - white*black) ) / valid ;
  sd=var**0.5 ;
 
  

proc sort ;
  by type site count ;

data bwstat ;
  set bwstat ;
  keep type site white black valid variable net ;

/* output results */

proc print ;

run;


