****************************************************************
* Program name:  sales_units.sas
* Author:        Steve Ross
* Final Version: September 11, 2001
* Project:       Housing Discrimination Study (#06977-000-00)
*
* This program reads the raw data from the recommended homes
* from for sales tests.  This data is cleaned and is merged
* with census tract characteristics that are provided by the 
* Urban Institute.  The file also merges in home criteria
* from the tester assignments.
* 
* Input Files:	rechomes.ssd01, rechmdem.ssd01, fassign2.ssd01
* 
* Output Files:	rechome2.ssd01 
*
****************************************************************;

options nocenter ;

libname hds2000 '/mnt/jayhawk/jayproj/hds2000' ;
filename rechome2 '/mnt/jayhawk/jayproj/hds2000/rechome2.ssd01' ;
filename rechomes '/mnt/jayhawk/jayproj/hds2000/rechomes.ssd01' ;
filename rechmdem '/mnt/jayhawk/jayproj/hds2000/rechmdem.ssd01' ;
filename fassign2 '/mnt/jayhawk/jayproj/hds2000/fassign2.ssd01' ;

/* load data on housing units from sales tests */

data rechomes  ;
  set hds2000.rechomes ;
  count=1 ;

/* fix tester id's that have been manually verified by comparison 
with other q17 forms or with rental site visit report forms using
both the variable TESTERID and TESTER as a basis for comparison  */

  if control='CH-SB-2622' and testerid='WF-ISEN' then   
     testerid='WF-Isen' ;
  if control='CH-SB-2814' and testerid='BM-Curr' then   
     testerid='bm-curr' ;
  if control='CH-SB-2814' and testerid='WM-Scha' then   
     testerid='WM-SCHA' ;
  if control='CH-SH-2821' and testerid='H-F-10' then   
     testerid='h-f-10' ;
  if control='CH-SH-2821' and testerid='W-F-17' then   
     testerid='w-f-17' ;
  if control='CN-SH-3003' and testerid='HM-Sanc' then   
     testerid='HM-SANC' ;
  if control='CX-SH-2403' and testerid='h-f-05' then   
     testerid='H-F-05' ;
  if control='CX-SH-2403' and testerid='w-f-20' then   
     testerid='W-F-20' ;
  if control='DT-SB-0601' and testerid='DET' then   
     testerid='det-128' ;
  if control='DT-SB-0601' and testerid='DET 104' then   
     testerid='det-104' ;
  if control='DT-SB-1815' and testerid='DET-104' then   
     testerid='det-104' ;
  if control='DT-SB-2101' and testerid='DET-133' then   
     testerid='det-133' ;
  if control='DT-SB-2101' and testerid='DET-144' then   
     testerid='det-144' ;
  if control='LA-SH-1318' and testerid='373' then   
     testerid='373`' ;
  if control='LA-SK-1104' and testerid='150x' then   
     testerid='150' ;
  if control='MA-SB-1307' and testerid='16' then   
     testerid='016' ;
  if control='MA-SB-1307' and testerid='38' then   
     testerid='038' ;
  if control='MN-SS-0803' and testerid='w8' then   
     testerid='W8' ;
  if control='NY-SB-0305' and testerid='18' then   
     testerid='018' ;
  if control='NY-SB-0305' and testerid='34' then   
     testerid='034' ;
  if control='NY-SB-0401' and testerid='18' then   
     testerid='018' ;
  if control='NY-SB-0401' and testerid='34' then   
     testerid='034' ;

/* delete duplicate observations that were identified by UI */

  if del_rec=1 or duplicat=1 then delete ;
    else if (control='AU-SB-0801' and testerid='x01311')
      or (control='AU-SB-0801' and testerid='x01410')
      or (control='AU-SB-2102' and testerid='x01422')
      or (control='NN-SH-2201' and testerid='x28')
      or (control='NX-SB-1807' and testerid='x26')
        then delete ;
    else output rechomes ;

/* delete  additional duplicate observations by examining whether
multiple records exist for the same control number, tester id, and
unit sequence number */

proc sort data=rechomes ;
   by control testerid sequence ;
proc means data=rechomes noprint ;
   var count ;
   output out=mrechome sum=totcnt ;
   by control testerid sequence ;


data rechomes dup2 dup3 ;
  merge rechomes (in=q1) mrechome ;
   by control testerid sequence ;
  if q1 ;

  if totcnt=1 then  output rechomes ;
    else if totcnt=2 then output dup2 ;
    else output dup3 ;

data dup2 ;
  set dup2 ;

  if _N_ in (1, 3, 5, 7, 9, 11, 13, 15, 17, 19,
             21, 23, 25, 27, 29, 31, 33, 35, 37, 39,
             41, 43, 45, 47, 49, 51, 53, 55, 57, 59,
             61, 63, 65, 67, 69, 71, 73, 75, 77, 79,
             81, 83, 85, 87, 89, 91, 93, 95, 97, 99,
             101, 103, 105, 107, 109, 111, 113, 115, 117, 119,
             121, 123, 125, 127, 129, 131, 133, 135, 137, 139,
             141, 143, 145, 147, 149, 151, 153, 155, 157, 159,
             161, 163, 165, 167, 169, 171, 173, 175, 177, 179,
             181, 183, 185, 187, 189, 191, 193, 195, 197, 199,
             201, 203, 205, 207, 209, 211, 213, 215, 217, 219,
             221, 223, 225, 227, 229, 231, 233, 235, 237, 239,
             241, 243, 245, 247, 249, 251, 253, 255, 257, 259,
             261, 263, 265, 267, 269, 271, 273, 275, 277, 279,
             281, 283, 285, 287, 289, 291, 293, 295, 297, 299,  
             301, 303, 305, 307, 309, 311, 313, 315, 317, 319,
             321, 323, 325, 327, 329, 331, 333, 335, 337, 339,
             341, 343, 345, 347, 349, 351, 353, 355, 357, 359,
             361, 363, 365, 367, 369, 371, 373, 375, 377, 379,
             381, 383, 385, 387, 389, 391, 393, 395, 397, 399,
             401, 403, 405, 407, 409, 411, 413, 415, 417, 419,
             421, 423, 425, 427, 429, 431, 433, 435, 437, 439,
             441, 443, 445, 447, 449, 451, 453, 455, 457, 459,
             461, 463, 465, 467, 469, 471, 473, 475, 477, 479,
             481, 483, 485, 487, 489, 491, 493, 495, 497, 499,
             501, 503, 505, 507, 509, 511, 513, 515, 517, 519,
             521, 523, 525, 527 )


         then output dup2 ;
  else delete ;

data dup3 ;
  set dup3 ;
  if _N_ in (1, 4, 7, 10, 13, 16, 19, 22, 25, 28,
             31, 34, 37, 40, 43, 46, 49, 52, 55, 58,
             61, 64, 67, 70, 73, 76, 79, 82, 85, 88,
             91, 94 ) then output dup3 ;
   else delete ;


/* combine final sample of unique tests */

data rechomes ;
  set rechomes dup2 dup3 ;
  
proc sort ;
  by control testerid sequence ;

/* load geographic data for sales tests */

data rdem ;
   set hds2000.rechmdem ;
    aseq=trim(sequence) ; 
    stestid=trim(testerid) ;
    scontrol=trim(control) ;
    sequence=trim(sequence) ;
   keep scontrol aseq stestid mval00 pci00 pctblk pcthisp pctownoc
    povrat90 geo90 ;



data rdem ;
  set rdem ;
  length control $32 testerid $32 ;

   control=scontrol ;
   testerid=stestid ;

   sequence=input(aseq,8.) ;

proc sort ;
  by control testerid sequence ;

/* merge geographic data with sample of units */


data rechomes ;
  merge  rechomes (in=q1) rdem (in=q2) ;
     by control testerid sequence ;
     if q1 ;     

    match=q2 ;


proc sort ;
  by control ;


proc freq ;
  tables match ;

proc means ;
  var mval00 pci00 pctblk pcthisp pctownoc povrat90 ;

	
/* load cleaned sample of test assignments */

data assign ;
  set hds2000.fassign2 ;

/* develop average measures of assignments */

  if mbedmin=0 then mbedmin=. ;
  if wbedmin=0 then wbedmin=. ;

  if mbedmin=. and wbedmin=. then abedmin=. ;
    else if mbedmin=. then abedmin=wbedmin ;
    else if wbedmin=. then abedmin=mbedmin ;  
    else if mbedmin<=wbedmin then abedmin=mbedmin ;
    else abedmin=mbedmin ;
  if abedmin=0.5 then abedmin=1.0 ;

  if mbedreq=0 then mbedreq=. ;
  if wbedreq=0 then wbedreq=. ;

  if mbedreq=. and wbedreq=. then do ;
       abedreql=. ;
       abedrequ=. ;
       end ;
    else if mbedreq=. then do ;
       abedreql=wbedreq ;
       abedrequ=wbedreq ;
       end ;
    else if wbedreq=. then do ;
       abedreql=mbedreq ;  
       abedrequ=mbedreq ;  
       end ;
    else if mbedreq<=wbedreq then do ;
       abedreql=mbedreq ;
       abedrequ=wbedreq ;
       end ;
    else do ;
       abedreql=wbedreq ;
       abedrequ=mbedreq ;
       end ;
  if abedreql=0.5 then abedreql=1.0 ;
  if abedreql=1.5 then abedreql=1.0 ;
  if abedreql=2.5 then abedreql=2.0 ;
  if abedrequ=0.5 then abedrequ=1.0 ;
  if abedrequ=1.5 then abedrequ=2.0 ;
  if abedrequ=2.5 then abedrequ=3.0 ;
   

  if substr(control,4,1)='S' then output assign ;
    else delete ;
  keep control abedreql abedrequ abedmin ;

proc sort ;
  by control ;

/* merge average assignments with recommended homes sample */

data rechomes ;
  merge rechomes (in=q1) assign ;
   by control ;  if q1 ; 

/* save sales units to permenant sas data set */  

data hds2000.rechome2 ;
  set rechomes ;
  if mval00=0 then do ;
    mval00=. ; pci00=. ; pctblk=. ; pcthisp=. ;
    pctownoc=. ; povrat90=. ;
    end ;


proc means ;
  var mval00 pci00 pctblk pcthisp pctownoc povrat90 ;

run;
