****************************************************************
* Program name:  sales_visit.sas
* Project:       Housing Discrimination Study Phase I
*
*  Final version: November 8, 2001 by Steve Ross
*
*  This program generates a clean sample of first and second
*  sales site visits for all testers.  The site visits for both the
*  majority and minority testers are merged with the sample of 
*  paired assignments from fassign2.ssd01.  A final sample of
*  completed sales tests is created where each tester made at least
*  one visit to the real estate agency.  
*
* Input Files:   sales.ssd01, moresale.ssd01, fassign2.ssd01, smagsale.ssd01
*
* Output Files:  finsales.ssd01
*
*                                            
****************************************************************;

options nocenter ;

          libname hds2000 '/mnt/jayhawk/jayproj/hds2000' ;
  
          filename sales '/mnt/jayhawk/jayproj/hds2000/sales.ssd01' ;
          filename moresale '/mnt/jayhawk/jayproj/hds2000/moresale.ssd01' ;
          filename fassign2 '/mnt/jayhawk/jayproj/hds2000/fassign2.ssd01' ;
          filename finsales '/mnt/jayhawk/jayproj/hds2000/finsales.ssd01' ;
          filename smagsale '/mnt/jayhawk/jayproj/hds2000/smagsale.ssd01';
          filename seqsales '/mnt/jayhawk/jayproj/hds2000/seqsales.ssd01';

/*  create sample of all site visit report forms for sales tests */

          data sales ;
              set hds2000.sales (in=q1) hds2000.moresale (in=q2) ;
          if q1=1 then moresale=0 ;
          else if q2=1 then moresale=1 ;
          else moresale=-1 ;

/* Correct data entry errors on tester id's between the forms for
the first and second tester visits */

          if ssndvisi=1 then do ;
          if control='CH-SB-1104' and testerid='WF-Isen' then       
              testerid='WF-ISEN' ;
          if control='CH-SB-1204' and testerid='wf-kend' then       
              testerid='WF-KEND' ;
          if control='CH-SB-1302' and testerid='b-f-08' then        
              testerid='B-F-08' ;
          if control='CH-SB-2036' and testerid='WF-SHER' then       
              testerid='wf-sher' ;
          if control='CH-SB-2509' and testerid='BM-Curr' then       
              testerid='bm-curr' ;
          if control='CH-SB-2611' and testerid='BF-Tayl' then       
              testerid='bf-tayl' ;
          if control='CH-SB-2611' and testerid='WF-WEIS' then       
              testerid='wf-weis' ;
          if control='CH-SB-2830' and testerid='bf-tayl' then       
              testerid='BF-TAYL' ;
          if control='CH-SB-2830' and testerid='wf-sher' then       
              testerid='WF-Sher' ;
          if control='CH-SB-2845' and testerid='bf-tayl' then       
              testerid='BF-TAYL' ;
          if control='CH-SH-2519' and testerid='HF-RMil' then       
              testerid='HF-Rmil' ;
          if control='CH-SH-2820' and testerid='WF-Youn' then       
              testerid='WF-YOUN' ;
          if control='CH-SH-3041' and testerid='WF-Isen' then       
              testerid='WF-ISEN' ;
          if control='CH-SH-3056' and testerid='wf-young' then      
              testerid='wf-Young' ;
          if control='CN-SB-2123' and testerid='w-m-01' then        
              testerid='w-m-o1' ;
          if control='CN-SH-2105' and testerid='WM-COUN' then       
              testerid='WM-Coun' ;
          if control='TC-SH-2014' and testerid='84c' then           
              testerid='84C' ;
          end ;

          if control='DN-SH-0504' and testerid='09x' then            
              testerid='09' ;

/* do not delete these observations.  UI labelled these tests
as duplicates, but they are unique.  Problem could have
arisen due to data entry errors on testerid   */

          if control='PU-SH-1818' and testerid='407' then 
              duplicat=0 ;

          if control='AU-SB-2216' and testerid='01-423' then do ;
              duplicat=0 ; del_rec=0 ; end ;

          if control='BR-SB-1207' and testerid='26' then do ;
              duplicat=0 ; del_rec=0 ; end ;

          if control='MA-SB-1308' and testerid='26' then do ;
              duplicat=0 ; del_rec=0 ; end ;

          if control='SN-SH-2253' and testerid='228' then do ;
              duplicat=0 ; del_rec=0 ; end ;


/* delete duplicate observations */

              if del_rec=1 or duplicat=1 then delete ;
          else if control='DN-SH-0504' and testerid='406x' then delete ;
          else if control='LA-SB-1208' and testerid='13x' then delete ;
          else if control='LA-SK-0802' and testerid='150x' then delete ;
          else if control='LA-SK-1501' and testerid='150x' then delete ; 
          else if control='MA-SB-0302' and testerid='11x' then delete ;
          else if control='MA-SB-0511' and testerid='16x' then delete ;
          else if control='SD-SH-1106' and testerid='34x' then delete ;
                else output sales ;

          data sales ;
              set sales ;

/* fill in missing information in variables identifying second visit 
when inspection confirmed that another non-duplicate record represented
the first visit */ 

          if control='DN-SH-1401' and testerid='512'  and
              ssndvisi=0.00000 then ssndvisi=1 ;
          if control='DS-SB-1007' and testerid='9'    and
              ssndvisi=0.00000 then ssndvisi=1 ;
          if control='LA-SK-0909' and testerid='150'  and
              ssndvisi=0.00000 then ssndvisi=1 ;
          if control='LN-SB-1529' and testerid='92'   and
              ssndvisi=0.00000 then ssndvisi=2 ;
          if control='LN-SB-1529' and testerid='92'   and
              ssndvisi=2.00000 then ssndvisi=1 ;
          if control='MA-SB-1406' and testerid='30'   and
              ssndvisi=0.00000 then ssndvisi=1 ;
          if control='NO-SB-1021' and testerid='417'  and
              ssndvisi=0.00000 then ssndvisi=1 ;
          if control='NO-SB-1216' and testerid='417'  and
              ssndvisi=0.00000 then ssndvisi=1 ;
          if control='NO-SB-1320' and testerid='410'  and
              ssndvisi=0.00000 then ssndvisi=1 ;
          if control='PU-SH-1507' and testerid='125' and
              ssndvisi= 0.00000 then ssndvisi=1 ;
          if control='SD-SH-1602' and testerid='8' and
              ssndvisi=   0.00000 then ssndvisi=1 ;

/* fix variable identifying second visit when inspection two
non-duplicate visits are both coded as the second visit.  The 
presumption is that the test in sales.ssd01 is the first visit 
under those circumstances */

         if control='DN-SB-1208' and testerid='507' and
            moresale=0 then ssndvisi=2 ;
         if control='LN-SB-1529' and testerid='92' and
            moresale=0 then ssndvisi=2 ;
         if control='MA-SB-1423' and testerid='16' and
            moresale=0 then ssndvisi=2 ;


          if ssndvisi=1 then second=1 ;
            else second=0 ;
          count=1 ;

/* delete duplicates that were identified by inspection */

              if control='AT-SB-0202' and testerid='131'       
                 and moresale=1 and ssndvisi=2 then delete ;
              else if control='DN-SB-0610' and testerid='506'       
                 and moresale=1 and ssndvisi=2 then delete ;
              else if control='DN-SB-1807' and testerid='402'       
                 and moresale=1 and ssndvisi=2 then delete ;
              else if control='DS-SB-1301' and testerid='33'       
                 and  moresale=0 and ssndvisi=0 then delete ;
              else if control='DN-SH-1905' and testerid='40'       
                 and  moresale=1 and ssndvisi=2 then delete ;
              else if control='DS-SB-0204' and testerid='6'       
                 and  moresale=0 and ssndvisi=0 then delete ;
              else if control='DS-SB-0304' and testerid='6'       
                 and  moresale=0 and ssndvisi=0 then delete ;
              else if control='DS-SB-0610' and testerid='05'       
                 and  moresale=0 and ssndvisi=0 then delete ;
              else if control='LA-SK-1503' and testerid='132'       
                 and  moresale=0 and ssndvisi=0 then delete ;
              else if control='LN-SB-1707' and testerid='92'       
                 and  moresale=1 and ssndvisi=2 then delete ;
              else if control='MA-SB-0309' and testerid='30'       
                 and  moresale=1 and ssndvisi=1 then delete ;
              else if control='PT-SB-0705' and testerid='10'       
                 and  moresale=1 and ssndvisi=2 then delete ;
              else if control='PX-SN-1801' and testerid='100'       
                 and moresale=0 and ssndvisi=0 then delete ;
              else output sales ;     

/* create sample of first visits */

      data sales1 ;
        set sales ;
        if ssndvisi=2 or ssndvisi=0 then output sales1 ;
           else delete ;


     data sales1 ;
        set sales1 ;

/* more manual fixes of tester id's */

        if control='CH-SB-1104' and testerid='WF-ISEN' then testerid='WF-Isen';
        if control='CH-SB-1104' and testerid='bf-tayl' then testerid='BF-Tayl';
        if control='CH-SB-1204' and testerid='WF-KEND' then testerid='wf-kend';
        if control='CH-SB-1302' and testerid='B-F-08' then testerid='b-f-08';  
        if control='CH-SB-2036' and testerid='wf-sher' then testerid='WF-SHER';
        if control='CH-SB-2509' and testerid='bm-curr' then testerid='BM-Curr';
        if control='CH-SB-2611' and testerid='bf-tayl' then testerid='BF-Tayl';
        if control='CH-SB-2611' and testerid='wf-weis' then testerid='WF-WEIS';
        if control='CH-SB-2830' and testerid='BF-TAYL' then testerid='bf-tayl';
        if control='CH-SB-2830' and testerid='WF-Sher' then testerid='wf-sher';
        if control='CH-SB-2845' and testerid='BF-TAYL' then testerid='bf-tayl';
        if control='CH-SH-1407' and testerid='H-F-10' then testerid='h-f-10' ;
        if control='CH-SH-1503' and testerid='W-F-20' then testerid='w-f-20'; 
        if control='CH-SH-2519' and testerid='HF-Rmil' then testerid='HF-RMil';
        if control='CH-SH-2820' and testerid='WF-YOUN' then testerid='WF-Youn';
        if control='CH-SH-3041' and testerid='WF-ISEN' then testerid='WF-Isen';
        if control='CH-SH-3056' and testerid='wf-Young' then testerid=
               'wf-young'; 
        if control='CN-SB-2123' and testerid='w-m-o1' then testerid='w-m-01'; 
        if control='CN-SH-2105' and testerid='WM-Coun' then testerid='WM-COUN';
        if control='CX-SB-2408' and testerid='wf-isen' then testerid='wf-jsen';
        if control='LA-SH-1318' and testerid='373' then testerid='373`' ;   
        if control='TC-SH-2014' and testerid='84C' then testerid='84c' ;   

/* delete duplicate observations */

        if control='AU-SB-1907' and testerid='00410' then delete ;
        else if control='AU-SH-0901' and testerid='020-223' then delete ;
        else if control='CH-SB-0805' and testerid='WM-LINK' then delete ;
        else if control='CH-SB-2602' and testerid='bm-curr' then delete ;
        else if control='CH-SB-2622' and testerid='WF-ISEN' then delete ;
        else if control='CH-SB-2845' and testerid='wf-1sen' then delete ;
        else if control='CH-SH-1407' and testerid='H%3DF%3D10' then delete ;
        else if control='CH-SH-2821' and testerid='H-F-10' then delete ;
        else if control='CH-SH-2821' and testerid='W-F-17' then delete ;
        else if control='CH-SH-3041' and testerid='HF-URIB' then delete ;
        else if control='CH-SH-3041' and testerid='WF-SHEN' then delete ;
        else if control='CH-SH-3135' and testerid='WF-YOUN' then delete ;
        else if control='CH-SH-3459' and testerid='HM-SANC' then delete ;
        else if control='CN-SB-2123' and testerid='W-M-01' then delete ;
        else if control='DC-SB-0906' and testerid='300' then delete ;
        else if control='DN-SH-1702' and testerid='400' then delete ;
        else if control='DT-SB-0601' and testerid='DET' then delete ;
        else if control='DT-SB-0601' and testerid='DET 104' then delete ;
        else if control='DT-SB-1815' and testerid='DET-104' then delete ;
        else if control='DT-SB-2101' and testerid='DET-144' then delete ;
        else if control='MA-SB-1307' and testerid='16' then delete ;
        else if control='MA-SB-1307' and testerid='38' then delete ;
        else if control='NY-SB-0305' and testerid='18' then delete ;
        else if control='NY-SB-0305' and testerid='34' then delete ;
        else if control='NY-SB-0401' and testerid='18' then delete ;
        else if control='NY-SB-0401' and testerid='34' then delete ;
        else if control='NY-SB-0402' and testerid='026' then delete ;
        else if control='SD-SH-1004' and testerid='2' then delete ;
        else output sales1 ;

/* create sample of forms from second site visit */

      data sales2 ;
        set sales ;

        if ssndvisi=1 then output sales2 ;
           else delete ;

/* generate sample of sales tests from fassign2.ssd01 */

data assign ;
  set hds2000.fassign2 ;
  ntype=substr(control,4,1) ;

/* control number MN-RS-0804 is actually a sales test */

  if control='MN-RS-0804' then output assign ;
   else  if ntype='R' then delete ;
     else output assign ;

proc sort ;
  by control wtestid ;

/* save white treatment information from first visit */

data wsvrf1 ;
  set sales1 ;

  wtestid=testerid ;  
  wavladv=savlblad ;
  wsamebed=ssamebed ;
  wminbed=sminbed ;
  wtotunit=stotunit ;
  warngm1=sarngm1 ;
  warngm2=sarngm2 ;
  warngm3=sarngm3 ;
  warngm4=sarngm4 ;

  waskbank=saskbank ;
  wtelbank=stelbank ;
  wagqual=sagqual ;
  wagfindf=sagfindf ;
  waglndr=saglndr ;
  wrfixed=srfixed ;
  wradjst=sradjst ;
  wrfhava=srfhava ;
  wprequal=sprequal ;
  wqmarry=sqmarry ;
  wqfamsiz=sqfamsiz ;
  wqincome=sqincome ;
  wqoccup=sqoccup ;
  wqemplng=sqemplng ;
  wqasset=sqasset ;
  wqdebts=sqdebts ;
  wqcredit=sqcredit ;
  wqdownp=sqdownp ;
  wsugpric=ssugpric ;
  wpriclow=spriclow ;
  wprichi=sprichi ;
  wsugmort=ssugmort ;
  wmortlow=smortlow ;
  wmorthi=smorthi ;
  wsugrate=ssugrate ;
  wratelow=sratelow ;
  wratehi=sratehi ;
  wsugdown=ssugdown ;
  wdwnlowa=sdwnlowa ;
  wdwnhia=sdwnhia ;
  wdwnlowp=sdwnlowp ;
  wdwnhip=sdwnhip ;
  wsugpay=ssugpay ;
  wpaylow=spaylow ;
  wpayhi=spayhi ;
  wagpydn=sagpydn ;
  wagdbcn=sagdbcn ;
  wagcosn=sagcosn ;
  wagsela=sagsela ;
  wagprqu=sagprqu ;
  wagnods=sagnods ;

  wagmet1a=sagmetw1 ;
  wagmet2a=sagmetw2 ;
  wagnam1a=sagname1 ;
  wagnam2a=sagname2 ;
  wagnam3a=sagname3 ;
  wagnam4a=sagname4 ;
  wagnam5a=sagname5 ;

  wvdate_d=sdate_d ;
  wvdate_m=sdate_m ;
  wvdate_y=sdate_y ;

  wappt_h=sappt_h ;
  wappt_m=sappt_m ;
  wappt_am=sappt_am ;

  keep control wtestid wavladv wtotunit wagmet1a wagmet2a
    wagnam1a wagnam2a wagnam3a wagnam4a wagnam5a 
  wsamebed  wminbed   warngm1  warngm2
  warngm3  warngm4  waskbank  wtelbank  wagqual
  wagfindf  waglndr  wrfixed  wradjst  wrfhava
  wprequal  wqmarry  wqfamsiz  wqincome  wqoccup
  wqemplng  wqasset  wqdebts  wqcredit  wqdownp
  wsugpric  wpriclow  wprichi  wsugmort  wmortlow
  wmorthi  wsugrate  wratelow  wratehi  wsugdown
  wdwnlowa  wdwnhia  wdwnlowp  wdwnhip  wsugpay
  wpaylow  wpayhi  wagpydn  wagdbcn  wagcosn
  wagsela  wagprqu  wagnods
  wvdate_d wvdate_m wvdate_y wappt_h wappt_m wappt_am  ;


proc sort ;
  by control wtestid ;

/* save white treatment information from second visit */

data wsvrf2 ;
  set sales2 ;
  wtestid=testerid ;  
  wavladv2=savlblad ;
  wsamebe2=ssamebed ;
  wminbed2=sminbed ;
  wtotuni2=stotunit ;
  warngm12=sarngm1 ;
  warngm22=sarngm2 ;
  warngm32=sarngm3 ;
  warngm42=sarngm4 ;

  waskban2=saskbank ;
  wtelban2=stelbank ;
  wagqual2=sagqual ;
  wagfind2=sagfindf ;
  waglndr2=saglndr ;
  wrfixed2=srfixed ;
  wradjst2=sradjst ;
  wrfhava2=srfhava ;
  wprequa2=sprequal ;
  wqmarry2=sqmarry ;
  wqfamsi2=sqfamsiz ;
  wqincom2=sqincome ;
  wqoccup2=sqoccup ;
  wqempln2=sqemplng ;
  wqasset2=sqasset ;
  wqdebts2=sqdebts ;
  wqcredi2=sqcredit ;
  wqdownp2=sqdownp ;
  wsugpri2=ssugpric ;
  wpriclo2=spriclow ;
  wprichi2=sprichi ;
  wsugmor2=ssugmort ;
  wmortlo2=smortlow ;
  wmorthi2=smorthi ;
  wsugrat2=ssugrate ;
  wratelo2=sratelow ;
  wratehi2=sratehi ;
  wsugdow2=ssugdown ;
  wdwnloa2=sdwnlowa ;
  wdwnhia2=sdwnhia ;
  wdwnlop2=sdwnlowp ;
  wdwnhip2=sdwnhip ;
  wsugpay2=ssugpay ;
  wpaylow2=spaylow ;
  wpayhi2=spayhi ;
  wagpydn2=sagpydn ;
  wagdbcn2=sagdbcn ;
  wagcosn2=sagcosn ;
  wagsela2=sagsela ;
  wagprqu2=sagprqu ;
  wagnods2=sagnods ;



  wagmet1b=sagmetw1 ;
  wagmet2b=sagmetw2 ;
  wagnam1b=sagname1 ;
  wagnam2b=sagname2 ;
  wagnam3b=sagname3 ;
  wagnam4b=sagname4 ;
  wagnam5b=sagname5 ;

  wvdat2_d=sdate_d ;
  wvdat2_m=sdate_m ;
  wvdat2_y=sdate_y ;

  wapp2_h=sappt_h ;
  wapp2_m=sappt_m ;
  wapp2_am=sappt_am ;



  keep control wtestid wavladv2 wtotuni2 wagmet1b wagmet2b
    wagnam1b wagnam2b wagnam3b wagnam4b wagnam5b 
  wsamebe2  wminbed2   warngm12
  warngm22  warngm32  warngm42  waskban2  wtelban2
  wagqual2  wagfind2  waglndr2  wrfixed2  wradjst2
  wrfhava2  wprequa2  wqmarry2  wqfamsi2  wqincom2
  wqoccup2  wqempln2  wqasset2  wqdebts2  wqcredi2
  wqdownp2  wsugpri2  wpriclo2  wprichi2  wsugmor2
  wmortlo2  wmorthi2  wsugrat2  wratelo2  wratehi2
  wsugdow2  wdwnloa2  wdwnhia2  wdwnlop2  wdwnhip2
  wsugpay2  wpaylow2  wpayhi2  wagpydn2  wagdbcn2
  wagcosn2  wagsela2  wagprqu2  wagnods2 
  wvdat2_d wvdat2_m wvdat2_y wapp2_h wapp2_m wapp2_am  ;


proc sort ;
  by control wtestid ;

/* merge white treatment information with sample of tests */

data assign ;
  merge assign (in=q1) wsvrf1 (in=q2) wsvrf2 (in=q3) ;
    by control wtestid ;
  wsvrf1=q2 ;
  wsvrf2=q3 ;
  if q1 then output assign ;
      else delete ;

proc sort data=assign ;
  by control mtestid ;

/* save minority treatment information from first visit */

data msvrf1 ;
  set sales1 ;

  mtestid=testerid ;  
  mavladv=savlblad ;
  msamebed=ssamebed ;
  mminbed=sminbed ;
  mtotunit=stotunit ;
  marngm1=sarngm1 ;
  marngm2=sarngm2 ;
  marngm3=sarngm3 ;
  marngm4=sarngm4 ;

  maskbank=saskbank ;
  mtelbank=stelbank ;
  magqual=sagqual ;
  magfindf=sagfindf ;
  maglndr=saglndr ;
  mrfixed=srfixed ;
  mradjst=sradjst ;
  mrfhava=srfhava ;
  mprequal=sprequal ;
  mqmarry=sqmarry ;
  mqfamsiz=sqfamsiz ;
  mqincome=sqincome ;
  mqoccup=sqoccup ;
  mqemplng=sqemplng ;
  mqasset=sqasset ;
  mqdebts=sqdebts ;
  mqcredit=sqcredit ;
  mqdownp=sqdownp ;
  msugpric=ssugpric ;
  mpriclow=spriclow ;
  mprichi=sprichi ;
  msugmort=ssugmort ;
  mmortlow=smortlow ;
  mmorthi=smorthi ;
  msugrate=ssugrate ;
  mratelow=sratelow ;
  mratehi=sratehi ;
  msugdown=ssugdown ;
  mdwnlowa=sdwnlowa ;
  mdwnhia=sdwnhia ;
  mdwnlowp=sdwnlowp ;
  mdwnhip=sdwnhip ;
  msugpay=ssugpay ;
  mpaylow=spaylow ;
  mpayhi=spayhi ;
  magpydn=sagpydn ;
  magdbcn=sagdbcn ;
  magcosn=sagcosn ;
  magsela=sagsela ;
  magprqu=sagprqu ;
  magnods=sagnods ;

  magmet1a=sagmetw1 ;
  magmet2a=sagmetw2 ;
  magnam1a=sagname1 ;
  magnam2a=sagname2 ;
  magnam3a=sagname3 ;
  magnam4a=sagname4 ;
  magnam5a=sagname5 ;

  mvdate_d=sdate_d ;
  mvdate_m=sdate_m ;
  mvdate_y=sdate_y ;

  mappt_h=sappt_h ;
  mappt_m=sappt_m ;
  mappt_am=sappt_am ;



  keep control mtestid mavladv mtotunit magmet1a magmet2a
    magnam1a magnam2a magnam3a magnam4a magnam5a
  msamebed  mminbed  marngm1  marngm2
  marngm3  marngm4  maskbank  mtelbank  magqual
  magfindf  maglndr  mrfixed  mradjst  mrfhava
  mprequal  mqmarry  mqfamsiz  mqincome  mqoccup
  mqemplng  mqasset  mqdebts  mqcredit  mqdownp
  msugpric  mpriclow  mprichi  msugmort  mmortlow
  mmorthi  msugrate  mratelow  mratehi  msugdown
  mdwnlowa  mdwnhia  mdwnlowp  mdwnhip  msugpay
  mpaylow  mpayhi  magpydn  magdbcn  magcosn
  magsela  magprqu  magnods 
  mvdate_d mvdate_m mvdate_y mappt_h mappt_m mappt_am  ;


proc sort ;
  by control mtestid ;

/* save minority treatment information from second visit */

data msvrf2 ;
  set sales2 ;
  mtestid=testerid ;  
  mavladv2=savlblad ;
  msamebe2=ssamebed ;
  mminbed2=sminbed ;
  mtotuni2=stotunit ;
  marngm12=sarngm1 ;
  marngm22=sarngm2 ;
  marngm32=sarngm3 ;
  marngm42=sarngm4 ;

  maskban2=saskbank ;
  mtelban2=stelbank ;
  magqual2=sagqual ;
  magfind2=sagfindf ;
  maglndr2=saglndr ;
  mrfixed2=srfixed ;
  mradjst2=sradjst ;
  mrfhava2=srfhava ;
  mprequa2=sprequal ;
  mqmarry2=sqmarry ;
  mqfamsi2=sqfamsiz ;
  mqincom2=sqincome ;
  mqoccup2=sqoccup ;
  mqempln2=sqemplng ;
  mqasset2=sqasset ;
  mqdebts2=sqdebts ;
  mqcredi2=sqcredit ;
  mqdownp2=sqdownp ;
  msugpri2=ssugpric ;
  mpriclo2=spriclow ;
  mprichi2=sprichi ;
  msugmor2=ssugmort ;
  mmortlo2=smortlow ;
  mmorthi2=smorthi ;
  msugrat2=ssugrate ;
  mratelo2=sratelow ;
  mratehi2=sratehi ;
  msugdow2=ssugdown ;
  mdwnloa2=sdwnlowa ;
  mdwnhia2=sdwnhia ;
  mdwnlop2=sdwnlowp ;
  mdwnhip2=sdwnhip ;
  msugpay2=ssugpay ;
  mpaylow2=spaylow ;
  mpayhi2=spayhi ;
  magpydn2=sagpydn ;
  magdbcn2=sagdbcn ;
  magcosn2=sagcosn ;
  magsela2=sagsela ;
  magprqu2=sagprqu ;
  magnods2=sagnods ;

  magmet1b=sagmetw1 ;
  magmet2b=sagmetw2 ;
  magnam1b=sagname1 ;
  magnam2b=sagname2 ;
  magnam3b=sagname3 ;
  magnam4b=sagname4 ;
  magnam5b=sagname5 ;

  mvdat2_d=sdate_d ;
  mvdat2_m=sdate_m ;
  mvdat2_y=sdate_y ;

  mapp2_h=sappt_h ;
  mapp2_m=sappt_m ;
  mapp2_am=sappt_am ;



  keep control mtestid mavladv2 mtotuni2 magmet1b magmet2b
    magnam1b magnam2b magnam3b magnam4b magnam5b 
  msamebe2  mminbed2   marngm12
  marngm22  marngm32  marngm42  maskban2  mtelban2
  magqual2  magfind2  maglndr2  mrfixed2  mradjst2
  mrfhava2  mprequa2  mqmarry2  mqfamsi2  mqincom2
  mqoccup2  mqempln2  mqasset2  mqdebts2  mqcredi2
  mqdownp2  msugpri2  mpriclo2  mprichi2  msugmor2
  mmortlo2  mmorthi2  msugrat2  mratelo2  mratehi2
  msugdow2  mdwnloa2  mdwnhia2  mdwnlop2  mdwnhip2
  msugpay2  mpaylow2  mpayhi2  magpydn2  magdbcn2
  magcosn2  magsela2  magprqu2  magnods2 
  mvdat2_d mvdat2_m mvdat2_y mapp2_h mapp2_m mapp2_am  ;


proc sort ;
  by control mtestid ;

/* merge minority treatment information with sample of tests */

data assign ;
  merge assign (in=q1) msvrf1 (in=q2) msvrf2 (in=q3) ;
    by control mtestid ;
  msvrf1=q2 ;
  msvrf2=q3 ;
  if q1 then output assign ;
      else delete ;

/* keep tests where a site visit was completed by both testers and
save whether a first visit, second visit, or both was present in the
data  */

data finsales problem ;
  set assign ;
  nsite=substr(control,1,2) ;
  if  (msvrf1=1 or msvrf2=1) and (wsvrf1=1 or wsvrf2=1) then output 
         finsales ;
    else output problem ;

 proc sort data=finsales ;
      by control ;

proc freq data=finsales ;
  tables nsite ;


/* Merge in information about whether testers saw the sameagent.  This
variable was created by a manual inspection of agent names.  The names
were taken from the variables WAGNAME1-5 and the actual agent was
identified by the testers self-report concerning who they met with which
is contained in WAGMETW.  This information is stored in the variable
binary which is one if they saw the same agent */

          data smagsale ;
            set hds2000.smagsale ;
            sameagnt=binary ;
            keep control sameagnt ;

          proc sort ;
            by control ;

/* load information on assigned visit order */

          data seqsales ;
            set hds2000.seqsales ;
            order=sequence ;
            keep control order ;

          proc sort ;
            by control ;


/* create final sales test sample */

          data hds2000.finsales ;
            merge finsales (in=q1) smagsale seqsales ;
              by control ; if q1 ;

          proc freq ;  tables sameagnt ;

          run;





